@@ -24,15 +24,15 @@ namespace Calamares
 
 CppJob::CppJob( QObject* parent )
     : Job( parent )
-{}
+{
+}
 
 
-CppJob::~CppJob()
-{}
+CppJob::~CppJob() {}
 
 
 void
-CppJob::setModuleInstanceKey( const QString& instanceKey )
+CppJob::setModuleInstanceKey( const Calamares::ModuleSystem::InstanceKey& instanceKey )
 {
     m_instanceKey = instanceKey;
 }
@@ -44,4 +44,4 @@ CppJob::setConfigurationMap( const QVariantMap& configurationMap )
     Q_UNUSED( configurationMap )
 }
 
-}
+}  // namespace Calamares
