@@ -27,17 +27,6 @@
 #include <QFile>
 #include <QJsonDocument>
 
-#ifdef WITH_PYTHON
-#include "PythonHelper.h"
-
-
-#undef slots
-#include <boost/python/list.hpp>
-#include <boost/python/str.hpp>
-
-namespace bp = boost::python;
-#endif
-
 using CalamaresUtils::operator""_MiB;
 
 namespace Calamares
@@ -167,75 +156,3 @@ GlobalStorage::loadYaml( const QString& filename )
 
 
 }  // namespace Calamares
-
-#ifdef WITH_PYTHON
-
-namespace CalamaresPython
-{
-
-Calamares::GlobalStorage* GlobalStoragePythonWrapper::s_gs_instance = nullptr;
-
-// The special handling for nullptr is only for the testing
-// script for the python bindings, which passes in None;
-// normal use will have a GlobalStorage from JobQueue::instance()
-// passed in. Testing use will leak the allocated GlobalStorage
-// object, but that's OK for testing.
-GlobalStoragePythonWrapper::GlobalStoragePythonWrapper( Calamares::GlobalStorage* gs )
-    : m_gs( gs ? gs : s_gs_instance )
-{
-    if ( !m_gs )
-    {
-        s_gs_instance = new Calamares::GlobalStorage;
-        m_gs = s_gs_instance;
-    }
-}
-
-bool
-GlobalStoragePythonWrapper::contains( const std::string& key ) const
-{
-    return m_gs->contains( QString::fromStdString( key ) );
-}
-
-
-int
-GlobalStoragePythonWrapper::count() const
-{
-    return m_gs->count();
-}
-
-
-void
-GlobalStoragePythonWrapper::insert( const std::string& key, const bp::object& value )
-{
-    m_gs->insert( QString::fromStdString( key ), CalamaresPython::variantFromPyObject( value ) );
-}
-
-bp::list
-GlobalStoragePythonWrapper::keys() const
-{
-    bp::list pyList;
-    const auto keys = m_gs->keys();
-    for ( const QString& key : keys )
-    {
-        pyList.append( key.toStdString() );
-    }
-    return pyList;
-}
-
-
-int
-GlobalStoragePythonWrapper::remove( const std::string& key )
-{
-    return m_gs->remove( QString::fromStdString( key ) );
-}
-
-
-bp::object
-GlobalStoragePythonWrapper::value( const std::string& key ) const
-{
-    return CalamaresPython::variantToPyObject( m_gs->value( QString::fromStdString( key ) ) );
-}
-
-}  // namespace CalamaresPython
-
-#endif  // WITH_PYTHON
