@@ -59,6 +59,6 @@ private:
     GlobalStorage* m_storage;
 };
 
-}
+}  // namespace Calamares
 
-#endif // CALAMARES_JOBQUEUE_H
+#endif  // CALAMARES_JOBQUEUE_H
