@@ -25,40 +25,38 @@
 #include <QDir>
 #include <QProcess>
 
-namespace Calamares {
+namespace Calamares
+{
 
 
 ProcessJob::ProcessJob( const QString& command,
                         const QString& workingPath,
                         bool runInChroot,
-                        int secondsTimeout,
+                        std::chrono::seconds secondsTimeout,
                         QObject* parent )
     : Job( parent )
     , m_command( command )
     , m_workingPath( workingPath )
     , m_runInChroot( runInChroot )
     , m_timeoutSec( secondsTimeout )
-{}
+{
+}
 
 
-ProcessJob::~ProcessJob()
-{}
+ProcessJob::~ProcessJob() {}
 
 
 QString
 ProcessJob::prettyName() const
 {
-    return ( m_runInChroot ? tr( "Run command '%1' in target system." ) : tr( " Run command '%1'." ) )
-            .arg( m_command );
+    return ( m_runInChroot ? tr( "Run command '%1' in target system." ) : tr( " Run command '%1'." ) ).arg( m_command );
 }
 
 
 QString
 ProcessJob::prettyStatusMessage() const
 {
-    return tr( "Running command %1 %2" )
-            .arg( m_command )
-            .arg( m_runInChroot ? "in chroot." : " ." );
+    return tr( "Running command %1 %2" ).arg( m_command ).arg( m_runInChroot ? "in chroot." : " ." );
 }
 
 
@@ -68,20 +66,16 @@ ProcessJob::exec()
     using CalamaresUtils::System;
 
     if ( m_runInChroot )
-        return CalamaresUtils::System::instance()->
-             targetEnvCommand( { m_command },
-                              m_workingPath,
-                              QString(),
-                              m_timeoutSec )
-             .explainProcess( m_command, m_timeoutSec );
+        return CalamaresUtils::System::instance()
+            ->targetEnvCommand( { m_command }, m_workingPath, QString(), m_timeoutSec )
+            .explainProcess( m_command, m_timeoutSec );
     else
-        return
-            System::runCommand( System::RunLocation::RunInHost,
-                                { "/bin/sh", "-c", m_command },
-                                m_workingPath,
-                                QString(),
-                                m_timeoutSec )
+        return System::runCommand( System::RunLocation::RunInHost,
+                                   { "/bin/sh", "-c", m_command },
+                                   m_workingPath,
+                                   QString(),
+                                   m_timeoutSec )
             .explainProcess( m_command, m_timeoutSec );
 }
 
-} // namespace Calamares
+}  // namespace Calamares
