@@ -29,12 +29,22 @@ namespace Partition
 static const NamedEnumTable< SizeUnit >&
 unitSuffixes()
 {
+    // *INDENT-OFF*
+    // clang-format off
     static const NamedEnumTable< SizeUnit > names {
-        { QStringLiteral( "%" ), SizeUnit::Percent }, { QStringLiteral( "K" ), SizeUnit::KiB },
-        { QStringLiteral( "KiB" ), SizeUnit::KiB },   { QStringLiteral( "M" ), SizeUnit::MiB },
-        { QStringLiteral( "MiB" ), SizeUnit::MiB },   { QStringLiteral( "G" ), SizeUnit::GiB },
-        { QStringLiteral( "GiB" ), SizeUnit::GiB }
+        { QStringLiteral( "%" ), SizeUnit::Percent },
+        { QStringLiteral( "K" ), SizeUnit::KiB },
+        { QStringLiteral( "KiB" ), SizeUnit::KiB },
+        { QStringLiteral( "M" ), SizeUnit::MiB },
+        { QStringLiteral( "MiB" ), SizeUnit::MiB },
+        { QStringLiteral( "G" ), SizeUnit::GiB },
+        { QStringLiteral( "GiB" ), SizeUnit::GiB },
+        { QStringLiteral( "KB" ), SizeUnit::KB },
+        { QStringLiteral( "MB" ), SizeUnit::MB },
+        { QStringLiteral( "GB" ), SizeUnit::GB }
     };
+    // clang-format on
+    // *INDENT-ON*
 
     return names;
 }
@@ -50,7 +60,7 @@ PartitionSize::PartitionSize( const QString& s )
 
     if ( m_unit == SizeUnit::None )
     {
-        m_value = s.toInt();
+        m_value = s.toLongLong();
         if ( m_value > 0 )
         {
             m_unit = SizeUnit::Byte;
@@ -90,8 +100,11 @@ PartitionSize::toSectors( qint64 totalSectors, qint64 sectorSize ) const
             return totalSectors * value() / 100;
         }
     case SizeUnit::Byte:
+    case SizeUnit::KB:
     case SizeUnit::KiB:
+    case SizeUnit::MB:
     case SizeUnit::MiB:
+    case SizeUnit::GB:
     case SizeUnit::GiB:
         return CalamaresUtils::bytesToSectors( toBytes(), sectorSize );
     }
@@ -125,8 +138,11 @@ PartitionSize::toBytes( qint64 totalSectors, qint64 sectorSize ) const
             return totalSectors * value() / 100;
         }
     case SizeUnit::Byte:
+    case SizeUnit::KB:
     case SizeUnit::KiB:
+    case SizeUnit::MB:
     case SizeUnit::MiB:
+    case SizeUnit::GB:
     case SizeUnit::GiB:
         return toBytes();
     }
@@ -161,8 +177,11 @@ PartitionSize::toBytes( qint64 totalBytes ) const
             return totalBytes * value() / 100;
         }
     case SizeUnit::Byte:
+    case SizeUnit::KB:
     case SizeUnit::KiB:
+    case SizeUnit::MB:
     case SizeUnit::MiB:
+    case SizeUnit::GB:
     case SizeUnit::GiB:
         return toBytes();
     }
@@ -186,10 +205,16 @@ PartitionSize::toBytes() const
         return -1;
     case SizeUnit::Byte:
         return value();
+    case SizeUnit::KB:
+        return CalamaresUtils::KBtoBytes( static_cast< unsigned long long >( value() ) );
     case SizeUnit::KiB:
         return CalamaresUtils::KiBtoBytes( static_cast< unsigned long long >( value() ) );
+    case SizeUnit::MB:
+        return CalamaresUtils::MBtoBytes( static_cast< unsigned long long >( value() ) );
     case SizeUnit::MiB:
         return CalamaresUtils::MiBtoBytes( static_cast< unsigned long long >( value() ) );
+    case SizeUnit::GB:
+        return CalamaresUtils::GBtoBytes( static_cast< unsigned long long >( value() ) );
     case SizeUnit::GiB:
         return CalamaresUtils::GiBtoBytes( static_cast< unsigned long long >( value() ) );
     }
@@ -211,8 +236,11 @@ PartitionSize::operator<( const PartitionSize& other ) const
     case SizeUnit::Percent:
         return ( m_value < other.m_value );
     case SizeUnit::Byte:
+    case SizeUnit::KB:
     case SizeUnit::KiB:
+    case SizeUnit::MB:
     case SizeUnit::MiB:
+    case SizeUnit::GB:
     case SizeUnit::GiB:
         return ( toBytes() < other.toBytes() );
     }
@@ -234,8 +262,11 @@ PartitionSize::operator>( const PartitionSize& other ) const
     case SizeUnit::Percent:
         return ( m_value > other.m_value );
     case SizeUnit::Byte:
+    case SizeUnit::KB:
     case SizeUnit::KiB:
+    case SizeUnit::MB:
     case SizeUnit::MiB:
+    case SizeUnit::GB:
     case SizeUnit::GiB:
         return ( toBytes() > other.toBytes() );
     }
@@ -257,8 +288,11 @@ PartitionSize::operator==( const PartitionSize& other ) const
     case SizeUnit::Percent:
         return ( m_value == other.m_value );
     case SizeUnit::Byte:
+    case SizeUnit::KB:
     case SizeUnit::KiB:
+    case SizeUnit::MB:
     case SizeUnit::MiB:
+    case SizeUnit::GB:
     case SizeUnit::GiB:
         return ( toBytes() == other.toBytes() );
     }
