@@ -18,13 +18,17 @@
 
 #include "Retranslator.h"
 
-#include "Logger.h"
+#include "Settings.h"
+#include "utils/Dirs.h"
+#include "utils/Logger.h"
 
 #include <QCoreApplication>
 #include <QDir>
 #include <QEvent>
 #include <QTranslator>
 
+static bool s_allowLocalTranslations = false;
+
 /** @brief Helper class for loading translations
  *
  * This is used by the loadSingletonTranslator() function to hand off
@@ -125,34 +129,48 @@ BrandingLoader::tryLoad( QTranslator* translator )
     return false;
 }
 
-bool
-CalamaresLoader::tryLoad( QTranslator* translator )
+static bool
+tryLoad( QTranslator* translator, const QString& prefix, const QString& localeName )
 {
-    if ( translator->load( QString( ":/lang/calamares_" ) + m_localeName ) )
+    // In debug-mode, try loading from the current directory
+    if ( s_allowLocalTranslations && translator->load( prefix + localeName ) )
     {
-        cDebug() << Logger::SubEntry << "Calamares using locale:" << m_localeName;
+        cDebug() << Logger::SubEntry << "Loaded local translation" << prefix << localeName;
+        return true;
+    }
+
+    // Or load from appDataDir -- often /usr/share/calamares -- subdirectory land/
+    QDir localeData( CalamaresUtils::appDataDir() );
+    if ( localeData.exists()
+         && translator->load( localeData.absolutePath() + QStringLiteral( "/lang/" ) + prefix + localeName ) )
+    {
+        cDebug() << Logger::SubEntry << "Loaded appdata translation" << prefix << localeName;
+        return true;
+    }
+
+    // Or from QRC (most common)
+    if ( translator->load( QStringLiteral( ":/lang/" ) + prefix + localeName ) )
+    {
+        cDebug() << Logger::SubEntry << "Loaded QRC translation" << prefix << localeName;
         return true;
     }
     else
     {
-        cDebug() << Logger::SubEntry << "Calamares using default, system locale not found:" << m_localeName;
-        return translator->load( QString( ":/lang/calamares_en" ) );
+        cDebug() << Logger::SubEntry << "No translation for" << prefix << localeName << "using default (en)";
+        return translator->load( QStringLiteral( ":/lang/" ) + prefix + QStringLiteral( "en" ) );
     }
 }
 
+bool
+CalamaresLoader::tryLoad( QTranslator* translator )
+{
+    return ::tryLoad( translator, QStringLiteral( "calamares_" ), m_localeName );
+}
+
 bool
 TZLoader::tryLoad( QTranslator* translator )
 {
-    if ( translator->load( QString( ":/lang/tz_" ) + m_localeName ) )
-    {
-        cDebug() << Logger::SubEntry << "Calamares Timezones using locale:" << m_localeName;
-        return true;
-    }
-    else
-    {
-        cDebug() << Logger::SubEntry << "Calamares Timezones using default, system locale not found:" << m_localeName;
-        return translator->load( QString( ":/lang/tz_en" ) );
-    }
+    return ::tryLoad( translator, QStringLiteral( "tz_" ), m_localeName );
 }
 
 static void
@@ -245,5 +263,11 @@ Retranslator::eventFilter( QObject* obj, QEvent* e )
     return QObject::eventFilter( obj, e );
 }
 
+void
+setAllowLocalTranslation( bool allow )
+{
+    s_allowLocalTranslations = allow;
+}
+
 
 }  // namespace CalamaresUtils
