@@ -42,14 +42,30 @@ DLLEXPORT void installTranslator( const QLocale& locale, const QString& branding
 
 DLLEXPORT QString translatorLocaleName();
 
+/** @brief Set @p allow to true to load translations from current dir.
+ *
+ * If false, (or never called) the translations are loaded only from
+ * system locations (the AppData dir) and from QRC (compiled in).
+ * Enable local translations to test translations stored in the
+ * current directory.
+ */
+DLLEXPORT void setAllowLocalTranslation( bool allow );
+
 class Retranslator : public QObject
 {
     Q_OBJECT
 public:
+    /// @brief Call @p retranslateFunc when the language changes
     static void attachRetranslator( QObject* parent, std::function< void( void ) > retranslateFunc );
+    /// @brief What retranslator belongs to @p parent (may create one)
+    static Retranslator* retranslatorFor( QObject* parent );
 
+    /// @brief Call @p retranslateFunc when the language changes
     void addRetranslateFunc( std::function< void( void ) > retranslateFunc );
 
+signals:
+    void languageChange();
+
 protected:
     bool eventFilter( QObject* obj, QEvent* e ) override;
 
@@ -65,5 +81,12 @@ private:
 #define CALAMARES_RETRANSLATE( body ) CalamaresUtils::Retranslator::attachRetranslator( this, [=] { body } );
 #define CALAMARES_RETRANSLATE_WIDGET( widget, body ) \
     CalamaresUtils::Retranslator::attachRetranslator( widget, [=] { body } );
+#define CALAMARES_RETRANSLATE_SLOT( slotfunc ) \
+    { \
+        this->connect( CalamaresUtils::Retranslator::retranslatorFor( this ), \
+                       &CalamaresUtils::Retranslator::languageChange, \
+                       this, \
+                       slotfunc ); \
+    }
 
 #endif
