@@ -19,10 +19,14 @@
 #include "Tests.h"
 
 #include "CalamaresUtilsSystem.h"
+#include "Entropy.h"
 #include "Logger.h"
 #include "UMask.h"
 #include "Yaml.h"
 
+#include "GlobalStorage.h"
+#include "JobQueue.h"
+
 #include <QTemporaryFile>
 
 #include <QtTest/QtTest>
@@ -158,7 +162,7 @@ LibCalamaresTests::testUmask()
     // m gets the previous value of the mask (depends on the environment the
     // test is run in, might be 002, might be 077), ..
     mode_t m = CalamaresUtils::setUMask( 022 );
-    QCOMPARE( CalamaresUtils::setUMask( m ), 022 );  // But now most recently set was 022
+    QCOMPARE( CalamaresUtils::setUMask( m ), mode_t( 022 ) );  // But now most recently set was 022
 
     for ( mode_t i = 0; i <= 0777 /* octal! */; ++i )
     {
@@ -174,5 +178,76 @@ LibCalamaresTests::testUmask()
         QCOMPARE( unlink( name ), 0 );
     }
     QCOMPARE( CalamaresUtils::setUMask( 022 ), m );
-    QCOMPARE( CalamaresUtils::setUMask( m ), 022 );
+    QCOMPARE( CalamaresUtils::setUMask( m ), mode_t( 022 ) );
+}
+
+void
+LibCalamaresTests::testEntropy()
+{
+    QByteArray data;
+
+    auto r0 = CalamaresUtils::getEntropy( 0, data );
+    QCOMPARE( CalamaresUtils::EntropySource::None, r0 );
+    QCOMPARE( data.size(), 0 );
+
+    auto r1 = CalamaresUtils::getEntropy( 16, data );
+    QVERIFY( r1 != CalamaresUtils::EntropySource::None );
+    QCOMPARE( data.size(), 16 );
+    // This can randomly fail (but not often)
+    QVERIFY( data.at( data.size() - 1 ) != char( 0xcb ) );
+
+    auto r2 = CalamaresUtils::getEntropy( 8, data );
+    QVERIFY( r2 != CalamaresUtils::EntropySource::None );
+    QCOMPARE( data.size(), 8 );
+    QCOMPARE( r1, r2 );
+    // This can randomly fail (but not often)
+    QVERIFY( data.at( data.size() - 1 ) != char( 0xcb ) );
+}
+
+void
+LibCalamaresTests::testPrintableEntropy()
+{
+    QString s;
+
+    auto r0 = CalamaresUtils::getPrintableEntropy( 0, s );
+    QCOMPARE( CalamaresUtils::EntropySource::None, r0 );
+    QCOMPARE( s.length(), 0 );
+
+    auto r1 = CalamaresUtils::getPrintableEntropy( 16, s );
+    QVERIFY( r1 != CalamaresUtils::EntropySource::None );
+    QCOMPARE( s.length(), 16 );
+    for ( QChar c : s )
+    {
+        QVERIFY( c.isPrint() );
+        QCOMPARE( c.row(), uchar( 0 ) );
+        QVERIFY( c.cell() > 32 );  // ASCII SPACE
+        QVERIFY( c.cell() < 127 );
+    }
+}
+
+void
+LibCalamaresTests::testOddSizedPrintable()
+{
+    QString s;
+    for ( int l = 0; l <= 37; ++l )
+    {
+        auto r = CalamaresUtils::getPrintableEntropy( l, s );
+        if ( l == 0 )
+        {
+            QCOMPARE( r, CalamaresUtils::EntropySource::None );
+        }
+        else
+        {
+            QVERIFY( r != CalamaresUtils::EntropySource::None );
+        }
+        QCOMPARE( s.length(), l );
+
+        for ( QChar c : s )
+        {
+            QVERIFY( c.isPrint() );
+            QCOMPARE( c.row(), uchar( 0 ) );
+            QVERIFY( c.cell() > 32 );  // ASCII SPACE
+            QVERIFY( c.cell() < 127 );
+        }
+    }
 }
