@@ -61,10 +61,10 @@ getString( const QVariantMap& map, const QString& key )
     return QString();
 }
 
-int
-getInteger( const QVariantMap& map, const QString& key, int d )
+qint64
+getInteger( const QVariantMap& map, const QString& key, qint64 d )
 {
-    int result = d;
+    qint64 result = d;
     if ( map.contains( key ) )
     {
         auto v = map.value( key );
@@ -72,6 +72,10 @@ getInteger( const QVariantMap& map, const QString& key, int d )
         {
             result = v.toInt();
         }
+        else if ( v.type() == QVariant::LongLong )
+        {
+            result = v.toLongLong();
+        }
     }
 
     return result;
