@@ -3,6 +3,7 @@
  *   Copyright 2014-2015, Teo Mrnjavac <teo@kde.org>
  *   Copyright 2017-2018, Adriaan de Groot <groot@kde.org>
  *   Copyright 2018, Raul Rodrigo Segura (raurodse)
+ *   Copyright 2019, Camilo Higuita <milo.h@aol.com>
  *
  *   Calamares is free software: you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -21,7 +22,7 @@
 #ifndef BRANDING_H
 #define BRANDING_H
 
-#include "UiDllMacro.h"
+#include "DllMacro.h"
 
 #include "utils/NamedSuffix.h"
 
@@ -48,7 +49,7 @@ public:
      * e.g. *Branding::ProductName to get the string value for
      * the product name.
      */
-    enum StringEntry : short
+    enum StringEntry
     {
         ProductName,
         Version,
@@ -62,13 +63,16 @@ public:
         KnownIssuesUrl,
         ReleaseNotesUrl
     };
+    Q_ENUM( StringEntry )
 
     enum ImageEntry : short
     {
         ProductLogo,
         ProductIcon,
-        ProductWelcome
+        ProductWelcome,
+        ProductWallpaper
     };
+    Q_ENUM( ImageEntry )
 
     enum StyleEntry : short
     {
@@ -77,6 +81,7 @@ public:
         SidebarTextSelect,
         SidebarTextHighlight
     };
+    Q_ENUM( StyleEntry )
 
     /** @brief Setting for how much the main window may expand. */
     enum class WindowExpansion
@@ -85,6 +90,7 @@ public:
         Fullscreen,
         Fixed
     };
+    Q_ENUM( WindowExpansion )
     /** @brief Setting for the main window size.
      *
      * The units are pixels (Pixies) or something-based-on-fontsize (Fonties), which
@@ -96,6 +102,7 @@ public:
         Pixies,
         Fonties
     };
+    Q_ENUM( WindowDimensionUnit )
     class WindowDimension : public NamedSuffix< WindowDimensionUnit, WindowDimensionUnit::None >
     {
     public:
@@ -139,9 +146,6 @@ public:
     QString slideshowPath() const { return m_slideshowPath; }
     int slideshowAPI() const { return m_slideshowAPI; }
 
-    QString string( Branding::StringEntry stringEntry ) const;
-    QString styleString( Branding::StyleEntry styleEntry ) const;
-    QString imagePath( Branding::ImageEntry imageEntry ) const;
     QPixmap image( Branding::ImageEntry imageEntry, const QSize& size ) const;
 
     /** @brief Look up an image in the branding directory or as an icon
@@ -178,6 +182,11 @@ public:
      */
     void setGlobals( GlobalStorage* globalStorage ) const;
 
+public slots:
+    QString string( StringEntry stringEntry ) const;
+    QString styleString( StyleEntry styleEntry ) const;
+    QString imagePath( ImageEntry imageEntry ) const;
+
 private:
     static Branding* s_instance;
 
