@@ -21,7 +21,7 @@
 
 #include "Module.h"
 
-#include "UiDllMacro.h"
+#include "DllMacro.h"
 
 namespace Calamares
 {
