@@ -20,34 +20,26 @@
 
 #include "utils/PythonQtUtils.h"
 
-PythonQtJob::PythonQtJob( PythonQtObjectPtr cxt,
-                          PythonQtObjectPtr pyJob,
-                          QObject* parent )
+PythonQtJob::PythonQtJob( PythonQtObjectPtr cxt, PythonQtObjectPtr pyJob, QObject* parent )
     : Calamares::Job( parent )
     , m_cxt( cxt )
     , m_pyJob( pyJob )
 {
-
 }
 
 
 QString
 PythonQtJob::prettyName() const
 {
-    return CalamaresUtils::lookupAndCall( m_pyJob,
-                                          { "prettyName",
-                                            "prettyname",
-                                            "pretty_name" } ).toString();
+    return CalamaresUtils::lookupAndCall( m_pyJob, { "prettyName", "prettyname", "pretty_name" } ).toString();
 }
 
 
 QString
 PythonQtJob::prettyDescription() const
 {
-    return CalamaresUtils::lookupAndCall( m_pyJob,
-                                          { "prettyDescription",
-                                            "prettydescription",
-                                            "pretty_description" } ).toString();
+    return CalamaresUtils::lookupAndCall( m_pyJob, { "prettyDescription", "prettydescription", "pretty_description" } )
+        .toString();
 }
 
 
@@ -55,9 +47,8 @@ QString
 PythonQtJob::prettyStatusMessage() const
 {
     return CalamaresUtils::lookupAndCall( m_pyJob,
-                                          { "prettyStatusMessage",
-                                            "prettystatusmessage",
-                                            "pretty_status_message" } ).toString();
+                                          { "prettyStatusMessage", "prettystatusmessage", "pretty_status_message" } )
+        .toString();
 }
 
 
@@ -66,12 +57,15 @@ PythonQtJob::exec()
 {
     QVariant response = m_pyJob.call( "exec" );
     if ( response.isNull() )
+    {
         return Calamares::JobResult::ok();
+    }
 
     QVariantMap map = response.toMap();
     if ( map.isEmpty() || map.value( "ok" ).toBool() )
+    {
         return Calamares::JobResult::ok();
+    }
 
-    return Calamares::JobResult::error( map.value( "message" ).toString(),
-                                        map.value( "details" ).toString() );
+    return Calamares::JobResult::error( map.value( "message" ).toString(), map.value( "details" ).toString() );
 }
