@@ -18,6 +18,14 @@
 
 #include "ResizeFSJob.h"
 
+#include "CalamaresVersion.h"
+#include "GlobalStorage.h"
+#include "JobQueue.h"
+#include "partition/PartitionIterator.h"
+#include "utils/Logger.h"
+#include "utils/Units.h"
+#include "utils/Variant.h"
+
 #include <QProcess>
 #include <QDateTime>
 #include <QThread>
@@ -29,17 +37,7 @@
 #include <kpmcore/ops/resizeoperation.h>
 #include <kpmcore/util/report.h>
 
-#include "CalamaresVersion.h"
-#include "JobQueue.h"
-#include "GlobalStorage.h"
-
-#include "utils/Logger.h"
-#include "utils/Units.h"
-#include "utils/Variant.h"
-
-// From partition module
-#include "core/PartitionIterator.h"
-
+using CalamaresUtils::Partition::PartitionIterator;
 
 ResizeFSJob::ResizeFSJob( QObject* parent )
     : Calamares::CppJob( parent )
@@ -60,13 +58,13 @@ ResizeFSJob::prettyName() const
 }
 
 ResizeFSJob::PartitionMatch
-ResizeFSJob::findPartition( CoreBackend* backend )
+ResizeFSJob::findPartition()
 {
     using DeviceList = QList< Device* >;
-#ifdef WITH_KPMCORE331API
-    DeviceList devices = backend->scanDevices( /* not includeReadOnly, not includeLoopback */ ScanFlag(0) );
+#if defined( WITH_KPMCORE4API )
+    DeviceList devices = m_kpmcore.backend()->scanDevices( /* not includeReadOnly, not includeLoopback */ ScanFlag(0) );
 #else
-    DeviceList devices = backend->scanDevices( /* excludeReadOnly */ true );
+    DeviceList devices = m_kpmcore.backend()->scanDevices( /* excludeReadOnly */ true );
 #endif
 
     cDebug() << "ResizeFSJob found" << devices.count() << "devices.";
@@ -172,35 +170,17 @@ ResizeFSJob::exec()
             tr( "Invalid configuration" ),
             tr( "The file-system resize job has an invalid configuration and will not run." ) );
 
-    // Get KPMCore
-    auto backend_p = CoreBackendManager::self()->backend();
-    if ( backend_p )
-        cDebug() << "KPMCore backend @" << ( void* )backend_p << backend_p->id() << backend_p->version();
-    else
-    {
-        cDebug() << "No KPMCore backend loaded yet";
-        QByteArray backendName = qgetenv( "KPMCORE_BACKEND" );
-        if ( !CoreBackendManager::self()->load( backendName.isEmpty() ? CoreBackendManager::defaultBackendName() : backendName ) )
-        {
-            cWarning() << "Could not load KPMCore backend.";
-            return Calamares::JobResult::error(
-                tr( "KPMCore not Available" ),
-                tr( "Calamares cannot start KPMCore for the file-system resize job." ) );
-        }
-
-        backend_p = CoreBackendManager::self()->backend();
-    }
-    if ( !backend_p )
+    if ( !m_kpmcore)
     {
         cWarning() << "Could not load KPMCore backend (2).";
         return Calamares::JobResult::error(
             tr( "KPMCore not Available" ),
             tr( "Calamares cannot start KPMCore for the file-system resize job." ) );
     }
-    backend_p->initFSSupport();  // Might not be enough, see below
+    m_kpmcore.backend()->initFSSupport();  // Might not be enough, see below
 
     // Now get the partition and FS we want to work on
-    PartitionMatch m = findPartition( backend_p );
+    PartitionMatch m = findPartition();
     if ( !m.first || !m.second )
         return Calamares::JobResult::error(
             tr( "Resize Failed" ),
