@@ -18,21 +18,21 @@
 
 #include "Tests.h"
 
+#include "ResizeFSJob.h"
+
 #include "GlobalStorage.h"
 #include "JobQueue.h"
 #include "Settings.h"
 
 #include "utils/Logger.h"
-#include "utils/YamlUtils.h"
+#include "utils/Yaml.h"
 
 #include <QtTest/QtTest>
 
 #include <QFileInfo>
 #include <QStringList>
 
-#define private public
-#include "ResizeFSJob.h"
-#undef private
+using SizeUnit = CalamaresUtils::Partition::SizeUnit;
 
 QTEST_GUILESS_MAIN( FSResizerTests )
 
@@ -55,10 +55,9 @@ void FSResizerTests::testConfigurationRobust()
 
     // Empty config
     j.setConfigurationMap( QVariantMap() );
-    QVERIFY( j.m_fsname.isEmpty() );
-    QVERIFY( j.m_devicename.isEmpty() );
-    QCOMPARE( j.m_size.unit(), ResizeFSJob::RelativeUnit::None );
-    QCOMPARE( j.m_atleast.unit(), ResizeFSJob::RelativeUnit::None );
+    QVERIFY( j.name().isEmpty() );
+    QCOMPARE( j.size().unit(), SizeUnit::None );
+    QCOMPARE( j.minimumSize().unit(), SizeUnit::None );
 
     // Config is missing fs and dev, so it isn't valid
     YAML::Node doc0 = YAML::Load( R"(---
@@ -66,12 +65,11 @@ size: 100%
 atleast: 600MiB
 )" );
     j.setConfigurationMap( CalamaresUtils::yamlMapToVariant( doc0 ).toMap() );
-    QVERIFY( j.m_fsname.isEmpty() );
-    QVERIFY( j.m_devicename.isEmpty() );
-    QCOMPARE( j.m_size.unit(), ResizeFSJob::RelativeUnit::None );
-    QCOMPARE( j.m_atleast.unit(), ResizeFSJob::RelativeUnit::None );
-    QCOMPARE( j.m_size.value(), 0 );
-    QCOMPARE( j.m_atleast.value(), 0 );
+    QVERIFY( j.name().isEmpty() );
+    QCOMPARE( j.size().unit(), SizeUnit::None );
+    QCOMPARE( j.minimumSize().unit(), SizeUnit::None );
+    QCOMPARE( j.size().value(), 0 );
+    QCOMPARE( j.minimumSize().value(), 0 );
 }
 
 void FSResizerTests::testConfigurationValues()
@@ -85,14 +83,14 @@ size: 100%
 atleast: 600MiB
 )" );
     j.setConfigurationMap( CalamaresUtils::yamlMapToVariant( doc0 ).toMap() );
-    QVERIFY( !j.m_fsname.isEmpty() );
-    QVERIFY( j.m_devicename.isEmpty() );
-    QCOMPARE( j.m_size.unit(), ResizeFSJob::RelativeUnit::Percent );
-    QCOMPARE( j.m_atleast.unit(), ResizeFSJob::RelativeUnit::Absolute );
-    QCOMPARE( j.m_size.value(), 100 );
-    QCOMPARE( j.m_atleast.value(), 600 );
+    QVERIFY( !j.name().isEmpty() );
+    QCOMPARE( j.name(), QString("/") );
+    QCOMPARE( j.size().unit(), SizeUnit::Percent );
+    QCOMPARE( j.minimumSize().unit(), SizeUnit::MiB );
+    QCOMPARE( j.size().value(), 100 );
+    QCOMPARE( j.minimumSize().value(), 600 );
 
-    // Silly config
+    // Silly config has bad atleast value
     doc0 = YAML::Load( R"(---
 fs: /
 dev: /dev/m00
@@ -100,14 +98,28 @@ size: 72  MiB
 atleast: 127 %
 )" );
     j.setConfigurationMap( CalamaresUtils::yamlMapToVariant( doc0 ).toMap() );
-    QVERIFY( !j.m_fsname.isEmpty() );
-    QVERIFY( !j.m_devicename.isEmpty() );
-    QCOMPARE( j.m_size.unit(), ResizeFSJob::RelativeUnit::Absolute );
-    QCOMPARE( j.m_atleast.unit(), ResizeFSJob::RelativeUnit::None );
-    QCOMPARE( j.m_size.value(), 72 );
-    QCOMPARE( j.m_atleast.value(), 0 );
+    QVERIFY( !j.name().isEmpty() );
+    QCOMPARE( j.name(), QString("/") );
+    QCOMPARE( j.size().unit(), SizeUnit::MiB );
+    QCOMPARE( j.minimumSize().unit(), SizeUnit::None );
+    QCOMPARE( j.size().value(), 72 );
+    QCOMPARE( j.minimumSize().value(), 0 );
 
-    // Silly config
+    // Silly config has bad atleast value
+    doc0 = YAML::Load( R"(---
+dev: /dev/m00
+size: 72  MiB
+atleast: 127 %
+)" );
+    j.setConfigurationMap( CalamaresUtils::yamlMapToVariant( doc0 ).toMap() );
+    QVERIFY( !j.name().isEmpty() );
+    QCOMPARE( j.name(), QString("/dev/m00") );
+    QCOMPARE( j.size().unit(), SizeUnit::MiB );
+    QCOMPARE( j.minimumSize().unit(), SizeUnit::None );
+    QCOMPARE( j.size().value(), 72 );
+    QCOMPARE( j.minimumSize().value(), 0 );
+
+    // Normal config
     doc0 = YAML::Load( R"(---
 fs: /
 # dev: /dev/m00
@@ -115,10 +127,10 @@ size: 71MiB
 # atleast: 127%
 )" );
     j.setConfigurationMap( CalamaresUtils::yamlMapToVariant( doc0 ).toMap() );
-    QVERIFY( !j.m_fsname.isEmpty() );
-    QVERIFY( j.m_devicename.isEmpty() );
-    QCOMPARE( j.m_size.unit(), ResizeFSJob::RelativeUnit::Absolute );
-    QCOMPARE( j.m_atleast.unit(), ResizeFSJob::RelativeUnit::None );
-    QCOMPARE( j.m_size.value(), 71 );
-    QCOMPARE( j.m_atleast.value(), 0 );
+    QVERIFY( !j.name().isEmpty() );
+    QCOMPARE( j.name(), QString("/") );
+    QCOMPARE( j.size().unit(), SizeUnit::MiB );
+    QCOMPARE( j.minimumSize().unit(), SizeUnit::None );
+    QCOMPARE( j.size().value(), 71 );
+    QCOMPARE( j.minimumSize().value(), 0 );
 }
