@@ -162,7 +162,6 @@ class FstabGenerator(object):
             return None
 
         mapper_name = partition["luksMapperName"]
-        mount_point = partition["mountPoint"]
         luks_uuid = partition["luksUuid"]
         if not mapper_name or not luks_uuid:
             return None
@@ -219,7 +218,6 @@ class FstabGenerator(object):
 
                 else:
                     dct = self.generate_fstab_line_info(partition)
-
                     if dct:
                         self.print_fstab_line(dct, file=fstab_file)
 
@@ -234,21 +232,32 @@ class FstabGenerator(object):
                 self.print_fstab_line(dct, file=fstab_file)
 
     def generate_fstab_line_info(self, partition):
-        """ Generates information for each fstab entry. """
+        """
+        Generates information (a dictionary of fstab-fields)
+        for the given @p partition.
+        """
+        # Some "fs" names need special handling in /etc/fstab, so remap them.
         filesystem = partition["fs"].lower()
+        filesystem = FS_MAP.get(filesystem, filesystem)
         has_luks = "luksMapperName" in partition
         mount_point = partition["mountPoint"]
         disk_name = disk_name_for_partition(partition)
         is_ssd = disk_name in self.ssd_disks
-        filesystem = FS_MAP.get(filesystem, filesystem)
 
+        # Swap partitions are called "linuxswap" by parted.
+        # That "fs" is visible in GS, but that gets mapped
+        # to "swap", above, because that's the spelling needed in /etc/fstab
         if not mount_point and not filesystem == "swap":
             return None
         if not mount_point:
             mount_point = "swap"
 
-        options = self.mount_options.get(filesystem,
-                                         self.mount_options["default"])
+        if filesystem == "swap" and not partition.get("claimed", None):
+            libcalamares.utils.debug("Ignoring foreign swap {!s} {!s}".format(disk_name, partition.get("uuid", None)))
+            return None
+
+        options = self.get_mount_options(filesystem, mount_point)
+
         if is_ssd:
             extra = self.ssd_extra_mount_options.get(filesystem)
 
@@ -266,12 +275,12 @@ class FstabGenerator(object):
             self.root_is_ssd = is_ssd
 
         if filesystem == "btrfs" and "subvol" in partition:
-            options="subvol={},".format(partition["subvol"]) + options
+            options = "subvol={},".format(partition["subvol"]) + options
 
         if has_luks:
-            device="/dev/mapper/" + partition["luksMapperName"]
+            device = "/dev/mapper/" + partition["luksMapperName"]
         else:
-            device="UUID=" + partition["uuid"]
+            device = "UUID=" + partition["uuid"]
 
         return dict(device=device,
                     mount_point=mount_point,
@@ -296,6 +305,16 @@ class FstabGenerator(object):
             if partition["mountPoint"]:
                 mkdir_p(self.root_mount_point + partition["mountPoint"])
 
+    def get_mount_options(self, filesystem, mount_point):
+        efiMountPoint = libcalamares.globalstorage.value("efiSystemPartition")
+        job_config = libcalamares.job.configuration
+
+        if (mount_point == efiMountPoint and "efiMountOptions" in job_config):
+            return job_config["efiMountOptions"]
+
+        return self.mount_options.get(filesystem,
+                                      self.mount_options["default"])
+
 
 def run():
     """ Configures fstab.
@@ -308,13 +327,17 @@ def run():
     root_mount_point = global_storage.value("rootMountPoint")
 
     if not partitions:
-        libcalamares.utils.warning("partitions is empty, {!s}".format(partitions))
+        libcalamares.utils.warning("partitions is empty, {!s}"
+                                   .format(partitions))
         return (_("Configuration Error"),
-                _("No partitions are defined for <pre>{!s}</pre> to use." ).format("fstab"))
+                _("No partitions are defined for <pre>{!s}</pre> to use.")
+                .format("fstab"))
     if not root_mount_point:
-        libcalamares.utils.warning("rootMountPoint is empty, {!s}".format(root_mount_point))
+        libcalamares.utils.warning("rootMountPoint is empty, {!s}"
+                                   .format(root_mount_point))
         return (_("Configuration Error"),
-                _("No root mount point is given for <pre>{!s}</pre> to use." ).format("fstab"))
+                _("No root mount point is given for <pre>{!s}</pre> to use.")
+                .format("fstab"))
 
     mount_options = conf["mountOptions"]
     ssd_extra_mount_options = conf.get("ssdExtraMountOptions", {})
