@@ -4,7 +4,7 @@
 # === This file is part of Calamares - <https://github.com/calamares> ===
 #
 #   Copyright 2014, Rohan Garg <rohan@kde.org>
-#   Copyright 2015,2019, Philip Müller <philm@manjaro.org>
+#   Copyright 2015,2019-2020, Philip Müller <philm@manjaro.org>
 #   Copyright 2017, Alf Gaida <agaida@sidution.org>
 #   Copyright 2019, Adriaan de Groot <groot@kde.org>
 #
@@ -137,6 +137,10 @@ def modify_mkinitcpio_conf(partitions, root_mount_point):
         hooks.append("plymouth")
 
     for partition in partitions:
+        if partition["fs"] == "linuxswap" and not partition.get("claimed", None):
+            # Skip foreign swap
+            continue
+
         if partition["fs"] == "linuxswap":
             swap_uuid = partition["uuid"]
             if "luksMapperName" in partition:
