@@ -44,6 +44,12 @@
 
 #include <algorithm>
 
+static const char mustAccept[] = "#acceptFrame { border: 1px solid red;"
+                                 "background-color: #fff6f6;"
+                                 "border-radius: 4px;"
+                                 "padding: 2px; }";
+static const char okAccept[] = "#acceptFrame { padding: 3px }";
+
 const NamedEnumTable< LicenseEntry::Type >&
 LicenseEntry::typeNames()
 {
@@ -72,6 +78,7 @@ LicenseEntry::LicenseEntry( const QVariantMap& conf )
     m_url = QUrl( conf[ "url" ].toString() );
 
     m_required = CalamaresUtils::getBool( conf, "required", false );
+    m_expand = CalamaresUtils::getBool( conf, "expand", false );
 
     bool ok = false;
     QString typeString = conf.value( "type", "software" ).toString();
@@ -97,81 +104,71 @@ LicensePage::LicensePage( QWidget* parent )
 {
     ui->setupUi( this );
 
-    ui->verticalLayout->insertSpacing( 1, CalamaresUtils::defaultFontHeight() );
+    // ui->verticalLayout->insertSpacing( 1, CalamaresUtils::defaultFontHeight() );
+    CalamaresUtils::unmarginLayout( ui->verticalLayout );
 
-    ui->mainText->setAlignment( Qt::AlignCenter );
     ui->mainText->setWordWrap( true );
     ui->mainText->setSizePolicy( QSizePolicy::Expanding, QSizePolicy::Minimum );
 
-    ui->additionalText->setWordWrap( true );
-
-    ui->verticalLayout->insertSpacing( 4, CalamaresUtils::defaultFontHeight() / 2 );
-
-    ui->verticalLayout->setContentsMargins( CalamaresUtils::defaultFontHeight(),
-                                            CalamaresUtils::defaultFontHeight() * 3,
-                                            CalamaresUtils::defaultFontHeight(),
-                                            CalamaresUtils::defaultFontHeight() );
-
     ui->acceptFrame->setFrameStyle( QFrame::NoFrame | QFrame::Plain );
-    ui->acceptFrame->setStyleSheet( "#acceptFrame { border: 1px solid red;"
-                                    "background-color: #fff6f6;"
-                                    "border-radius: 4px;"
-                                    "padding: 2px; }" );
+    ui->acceptFrame->setStyleSheet( mustAccept );
     ui->acceptFrame->layout()->setMargin( CalamaresUtils::defaultFontHeight() / 2 );
 
     updateGlobalStorage( false );  // Have not agreed yet
 
     connect( ui->acceptCheckBox, &QCheckBox::toggled, this, &LicensePage::checkAcceptance );
 
-    CALAMARES_RETRANSLATE( ui->acceptCheckBox->setText( tr( "I accept the terms and conditions above." ) ); )
+    CALAMARES_RETRANSLATE_SLOT( &LicensePage::retranslate )
 }
 
 void
 LicensePage::setEntries( const QList< LicenseEntry >& entriesList )
 {
     CalamaresUtils::clearLayout( ui->licenseEntriesLayout );
+
+    m_allLicensesOptional = true;
+
     m_entries.clear();
     m_entries.reserve( entriesList.count() );
-
-    auto isRequired = []( const LicenseEntry& e ) { return e.m_required; };
-    m_allLicensesOptional = std::none_of( entriesList.cbegin(), entriesList.cend(), isRequired );
-
-    checkAcceptance( false );
-
     for ( const LicenseEntry& entry : entriesList )
     {
         LicenseWidget* w = new LicenseWidget( entry );
         ui->licenseEntriesLayout->addWidget( w );
         m_entries.append( w );
+        m_allLicensesOptional &= !entry.isRequired();
     }
-    ui->licenseEntriesLayout->addStretch();
+    ui->licenseEntriesLayout->addSpacerItem( new QSpacerItem( 10, 10, QSizePolicy::Minimum, QSizePolicy::Expanding ) );
 
-    CALAMARES_RETRANSLATE_SLOT( &LicensePage::retranslate )
+    ui->acceptCheckBox->setChecked( false );
+    checkAcceptance( false );
 }
 
 void
 LicensePage::retranslate()
 {
+    ui->acceptCheckBox->setText( tr( "I accept the terms and conditions above." ) );
+
+    QString review = tr( "Please review the End User License Agreements (EULAs)." );
+    const auto br = QStringLiteral( "<br/>" );
+
     if ( !m_allLicensesOptional )
     {
-        ui->mainText->setText( tr( "<h1>License Agreement</h1>"
-                                   "This setup procedure will install proprietary "
-                                   "software that is subject to licensing terms." ) );
-        ui->additionalText->setText( tr( "Please review the End User License "
-                                         "Agreements (EULAs) above.<br/>"
-                                         "If you do not agree with the terms, the setup procedure cannot continue." ) );
+        ui->mainText->setText( tr( "This setup procedure will install proprietary "
+                                   "software that is subject to licensing terms." )
+                               + br + review );
+        QString mustAcceptText( tr( "If you do not agree with the terms, the setup procedure cannot continue." ) );
+        ui->acceptCheckBox->setToolTip( mustAcceptText );
     }
     else
     {
-        ui->mainText->setText( tr( "<h1>License Agreement</h1>"
-                                   "This setup procedure can install proprietary "
+        ui->mainText->setText( tr( "This setup procedure can install proprietary "
                                    "software that is subject to licensing terms "
                                    "in order to provide additional features and enhance the user "
-                                   "experience." ) );
-        ui->additionalText->setText( tr( "Please review the End User License "
-                                         "Agreements (EULAs) above.<br/>"
-                                         "If you do not agree with the terms, proprietary software will not "
-                                         "be installed, and open source alternatives will be used instead." ) );
+                                   "experience." )
+                               + br + review );
+        QString okAcceptText( tr( "If you do not agree with the terms, proprietary software will not "
+                                  "be installed, and open source alternatives will be used instead." ) );
+        ui->acceptCheckBox->setToolTip( okAcceptText );
     }
     ui->retranslateUi( this );
 
@@ -202,14 +199,11 @@ LicensePage::checkAcceptance( bool checked )
     m_isNextEnabled = checked || m_allLicensesOptional;
     if ( !m_isNextEnabled )
     {
-        ui->acceptFrame->setStyleSheet( "#acceptFrame { border: 1px solid red;"
-                                        "background-color: #fff8f8;"
-                                        "border-radius: 4px;"
-                                        "padding: 2px; }" );
+        ui->acceptFrame->setStyleSheet( mustAccept );
     }
     else
     {
-        ui->acceptFrame->setStyleSheet( "#acceptFrame { padding: 3px }" );
+        ui->acceptFrame->setStyleSheet( okAccept );
     }
     emit nextStatusChanged( m_isNextEnabled );
 }
