@@ -27,7 +27,7 @@
 #include "JobQueue.h"
 
 #include "geoip/Handler.h"
-
+#include "network/Manager.h"
 #include "utils/CalamaresUtilsGui.h"
 #include "utils/Logger.h"
 #include "utils/Variant.h"
@@ -35,56 +35,22 @@
 
 #include <QBoxLayout>
 #include <QLabel>
-#include <QNetworkRequest>
-#include <QNetworkReply>
 #include <QtConcurrent/QtConcurrentRun>
 
 
-CALAMARES_PLUGIN_FACTORY_DEFINITION( LocaleViewStepFactory, registerPlugin<LocaleViewStep>(); )
+CALAMARES_PLUGIN_FACTORY_DEFINITION( LocaleViewStepFactory, registerPlugin< LocaleViewStep >(); )
 
 LocaleViewStep::LocaleViewStep( QObject* parent )
     : Calamares::ViewStep( parent )
     , m_widget( new QWidget() )
-    , m_actualWidget( new LocalePage() )
+    , m_actualWidget( nullptr )
     , m_nextEnabled( false )
+    , m_geoip( nullptr )
 {
     QBoxLayout* mainLayout = new QHBoxLayout;
     m_widget->setLayout( mainLayout );
     CalamaresUtils::unmarginLayout( mainLayout );
 
-    m_waitingWidget = new WaitingWidget( tr( "Loading location data..." ) );
-    mainLayout->addWidget( m_waitingWidget );
-
-    connect( &m_initWatcher, &QFutureWatcher< void >::finished,
-             this, [=]
-    {
-        bool hasInternet = Calamares::JobQueue::instance()->globalStorage()
-                           ->value( "hasInternet" ).toBool();
-        if ( m_geoipUrl.isEmpty() || !hasInternet )
-            setUpPage();
-        else
-            fetchGeoIpTimezone();
-    });
-
-    QFuture< void > initFuture = QtConcurrent::run( [=]
-    {
-        LocaleGlobal::init();
-        if ( m_geoipUrl.isEmpty() )
-            return;
-
-        Calamares::GlobalStorage* gs = Calamares::JobQueue::instance()->globalStorage();
-
-        // Max 10sec wait for RequirementsChecker to finish, assuming the welcome
-        // module is used.
-        // If welcome is not used, either "hasInternet" should be set by other means,
-        // or the GeoIP feature should be disabled.
-        for ( int i = 0; i < 10; ++i )
-            if ( !gs->contains( "hasInternet" ) )
-                QThread::sleep( 1 );
-    } );
-
-    m_initWatcher.setFuture( initFuture );
-
     emit nextStatusChanged( m_nextEnabled );
 }
 
@@ -92,19 +58,22 @@ LocaleViewStep::LocaleViewStep( QObject* parent )
 LocaleViewStep::~LocaleViewStep()
 {
     if ( m_widget && m_widget->parent() == nullptr )
+    {
         m_widget->deleteLater();
+    }
 }
 
 
 void
 LocaleViewStep::setUpPage()
 {
-    m_actualWidget->init( m_startingTimezone.first,
-                          m_startingTimezone.second,
-                          m_localeGenPath );
-    m_widget->layout()->removeWidget( m_waitingWidget );
-    m_waitingWidget->deleteLater();
+    if ( !m_actualWidget )
+    {
+        m_actualWidget = new LocalePage();
+    }
+    m_actualWidget->init( m_startingTimezone.first, m_startingTimezone.second, m_localeGenPath );
     m_widget->layout()->addWidget( m_actualWidget );
+
     m_nextEnabled = true;
     emit nextStatusChanged( m_nextEnabled );
 }
@@ -113,16 +82,14 @@ LocaleViewStep::setUpPage()
 void
 LocaleViewStep::fetchGeoIpTimezone()
 {
-    CalamaresUtils::GeoIP::Handler h( m_geoipStyle, m_geoipUrl, m_geoipSelector );
-    if ( h.isValid() )
+    if ( m_geoip && m_geoip->isValid() )
     {
-        m_startingTimezone = h.get();
+        m_startingTimezone = m_geoip->get();
         if ( !m_startingTimezone.isValid() )
-            cWarning() << "GeoIP lookup at" << m_geoipUrl << "failed.";
+        {
+            cWarning() << "GeoIP lookup at" << m_geoip->url() << "failed.";
+        }
     }
-    else
-        cWarning() << "GeoIP Style" << m_geoipStyle << "is not recognized.";
-    setUpPage();
 }
 
 
@@ -175,7 +142,7 @@ LocaleViewStep::isAtEnd() const
 }
 
 
-QList< Calamares::job_ptr >
+Calamares::JobList
 LocaleViewStep::jobs() const
 {
     return m_jobs;
@@ -185,6 +152,10 @@ LocaleViewStep::jobs() const
 void
 LocaleViewStep::onActivate()
 {
+    if ( !m_actualWidget )
+    {
+        setUpPage();
+    }
     m_actualWidget->onActivate();
 }
 
@@ -192,18 +163,25 @@ LocaleViewStep::onActivate()
 void
 LocaleViewStep::onLeave()
 {
-    m_jobs.clear();
-    m_jobs.append( m_actualWidget->createJobs() );
+    if ( m_actualWidget )
+    {
+        m_jobs = m_actualWidget->createJobs();
+        m_prettyStatus = m_actualWidget->prettyStatus();
 
-    m_prettyStatus = m_actualWidget->prettyStatus();
+        auto map = m_actualWidget->localesMap();
+        QVariantMap vm;
+        for ( auto it = map.constBegin(); it != map.constEnd(); ++it )
+        {
+            vm.insert( it.key(), it.value() );
+        }
 
-    auto map = m_actualWidget->localesMap();
-    QVariantMap vm;
-    for ( auto it = map.constBegin(); it != map.constEnd(); ++it )
-        vm.insert( it.key(), it.value() );
-
-    Calamares::JobQueue::instance()->globalStorage()
-            ->insert( "localeConf", vm );
+        Calamares::JobQueue::instance()->globalStorage()->insert( "localeConf", vm );
+    }
+    else
+    {
+        m_jobs.clear();
+        Calamares::JobQueue::instance()->globalStorage()->remove( "localeConf" );
+    }
 }
 
 
@@ -218,35 +196,51 @@ LocaleViewStep::setConfigurationMap( const QVariantMap& configurationMap )
     }
     else
     {
-        m_startingTimezone = CalamaresUtils::GeoIP::RegionZonePair( QStringLiteral( "America" ), QStringLiteral( "New_York" ) );
+        m_startingTimezone
+            = CalamaresUtils::GeoIP::RegionZonePair( QStringLiteral( "America" ), QStringLiteral( "New_York" ) );
     }
 
     m_localeGenPath = CalamaresUtils::getString( configurationMap, "localeGenPath" );
     if ( m_localeGenPath.isEmpty() )
+    {
         m_localeGenPath = QStringLiteral( "/etc/locale.gen" );
+    }
 
     bool ok = false;
     QVariantMap geoip = CalamaresUtils::getSubMap( configurationMap, "geoip", ok );
     if ( ok )
     {
-        m_geoipUrl = CalamaresUtils::getString( geoip, "url" );
-        m_geoipStyle = CalamaresUtils::getString( geoip, "style" );
-        m_geoipSelector = CalamaresUtils::getString( geoip, "selector" );
-    }
-    else
-    {
-        // Optional
-        m_geoipUrl = CalamaresUtils::getString( configurationMap, "geoipUrl" );
-        m_geoipStyle = CalamaresUtils::getString( configurationMap, "geoipStyle" );
-        m_geoipSelector = CalamaresUtils::getString( configurationMap, "geoipSelector" );
+        QString url = CalamaresUtils::getString( geoip, "url" );
+        QString style = CalamaresUtils::getString( geoip, "style" );
+        QString selector = CalamaresUtils::getString( geoip, "selector" );
 
-        if ( !m_geoipUrl.isEmpty() && ( m_geoipStyle.isEmpty() || m_geoipStyle == "legacy" ) )
+        m_geoip = std::make_unique< CalamaresUtils::GeoIP::Handler >( style, url, selector );
+        if ( !m_geoip->isValid() )
         {
-            m_geoipStyle = "json";
-            m_geoipUrl.append( "/json/" );
+            cWarning() << "GeoIP Style" << style << "is not recognized.";
         }
-
-        if ( !m_geoipUrl.isEmpty() )
-            cWarning() << "Legacy-style GeoIP configuration is deprecated. Use geoip: map.";
     }
 }
+
+Calamares::RequirementsList
+LocaleViewStep::checkRequirements()
+{
+    LocaleGlobal::init();
+    if ( m_geoip && m_geoip->isValid() )
+    {
+        auto& network = CalamaresUtils::Network::Manager::instance();
+        if ( network.hasInternet() )
+        {
+            fetchGeoIpTimezone();
+        }
+        else
+        {
+            if ( network.synchronousPing( m_geoip->url() ) )
+            {
+                fetchGeoIpTimezone();
+            }
+        }
+    }
+
+    return Calamares::RequirementsList();
+}
