@@ -48,13 +48,13 @@ LocaleTests::testDefaultLocaleConfiguration()
 {
     LocaleConfiguration lc( "en_US.UTF-8" );
     QVERIFY( !lc.isEmpty() );
-    QCOMPARE( lc.language(), "en_US.UTF-8" );
-    QCOMPARE( lc.toBcp47(), "en" );
+    QCOMPARE( lc.language(), QStringLiteral( "en_US.UTF-8" ) );
+    QCOMPARE( lc.toBcp47(), QStringLiteral( "en" ) );
 
     LocaleConfiguration lc2( "de_DE.UTF-8" );
     QVERIFY( !lc2.isEmpty() );
-    QCOMPARE( lc2.language(), "de_DE.UTF-8" );
-    QCOMPARE( lc2.toBcp47(), "de" );
+    QCOMPARE( lc2.language(), QStringLiteral( "de_DE.UTF-8" ) );
+    QCOMPARE( lc2.toBcp47(), QStringLiteral( "de" ) );
 }
 
 void
@@ -62,18 +62,18 @@ LocaleTests::testSplitLocaleConfiguration()
 {
     LocaleConfiguration lc( "en_US.UTF-8", "de_DE.UTF-8" );
     QVERIFY( !lc.isEmpty() );
-    QCOMPARE( lc.language(), "en_US.UTF-8" );
-    QCOMPARE( lc.toBcp47(), "en" );
+    QCOMPARE( lc.language(), QStringLiteral( "en_US.UTF-8" ) );
+    QCOMPARE( lc.toBcp47(), QStringLiteral( "en" ) );
     QCOMPARE( lc.lc_numeric, QStringLiteral( "de_DE.UTF-8" ) );
 
     LocaleConfiguration lc2( "de_DE.UTF-8", "da_DK.UTF-8" );
     QVERIFY( !lc2.isEmpty() );
-    QCOMPARE( lc2.language(), "de_DE.UTF-8" );
-    QCOMPARE( lc2.toBcp47(), "de" );
-    QCOMPARE( lc2.lc_numeric, "da_DK.UTF-8" );
+    QCOMPARE( lc2.language(), QStringLiteral( "de_DE.UTF-8" ) );
+    QCOMPARE( lc2.toBcp47(), QStringLiteral( "de" ) );
+    QCOMPARE( lc2.lc_numeric, QStringLiteral( "da_DK.UTF-8" ) );
 
     LocaleConfiguration lc3( "da_DK.UTF-8", "de_DE.UTF-8" );
     QVERIFY( !lc3.isEmpty() );
-    QCOMPARE( lc3.toBcp47(), "da" );
-    QCOMPARE( lc3.lc_numeric, "de_DE.UTF-8" );
+    QCOMPARE( lc3.toBcp47(), QStringLiteral( "da" ) );
+    QCOMPARE( lc3.lc_numeric, QStringLiteral( "de_DE.UTF-8" ) );
 }
