@@ -20,10 +20,10 @@
 #ifndef NETINSTALLVIEWSTEP_H
 #define NETINSTALLVIEWSTEP_H
 
-#include <utils/PluginFactory.h>
-#include <viewpages/ViewStep.h>
-
-#include <PluginDllMacro.h>
+#include "DllMacro.h"
+#include "locale/TranslatableConfiguration.h"
+#include "utils/PluginFactory.h"
+#include "viewpages/ViewStep.h"
 
 #include <QVariant>
 
@@ -38,7 +38,6 @@ public:
     virtual ~NetInstallViewStep() override;
 
     QString prettyName() const override;
-    QString prettyStatus() const override;
 
     QWidget* widget() override;
 
@@ -63,11 +62,10 @@ public slots:
 private:
     NetInstallPage* m_widget;
     bool m_nextEnabled;
-    QString m_prettyStatus;
-
+    CalamaresUtils::Locale::TranslatedString* m_sidebarLabel;  // As it appears in the sidebar
     QList< Calamares::job_ptr > m_jobs;
 };
 
 CALAMARES_PLUGIN_FACTORY_DECLARATION( NetInstallViewStepFactory )
 
-#endif // NETINSTALLVIEWSTEP_H
+#endif  // NETINSTALLVIEWSTEP_H
