@@ -106,7 +106,7 @@ PackageModel::rowCount( const QModelIndex& parent ) const
 }
 
 int
-PackageModel::columnCount( const QModelIndex& parent ) const
+PackageModel::columnCount( const QModelIndex& ) const
 {
     return 2;
 }
