@@ -1,7 +1,7 @@
 /* === This file is part of Calamares - <https://github.com/calamares> ===
  *
  *   Copyright (c) 2017, Kyle Robbertze <kyle@aims.ac.za>
- *   Copyright 2017, Adriaan de Groot <groot@kde.org>
+ *   Copyright 2017, 2020, Adriaan de Groot <groot@kde.org>
  *
  *   Calamares is free software: you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -21,8 +21,8 @@
 #define PACKAGETREEITEM_H
 
 #include <QList>
-#include <QVariant>
 #include <QStandardItem>
+#include <QVariant>
 
 class PackageTreeItem : public QStandardItem
 {
@@ -37,6 +37,13 @@ public:
         bool isCritical = false;
         bool isHidden = false;
         Qt::CheckState selected = Qt::Unchecked;
+
+        /** @brief Turns this item into a variant for PackageOperations use
+         *
+         * For "plain" items, this is just the package name; items with
+         * scripts return a map. See the package module for how it's interpreted.
+         */
+        QVariant toOperation() const;
     };
     explicit PackageTreeItem( const ItemData& data, PackageTreeItem* parent = nullptr );
     explicit PackageTreeItem( const QString packageName, PackageTreeItem* parent = nullptr );
@@ -47,7 +54,6 @@ public:
     void appendChild( PackageTreeItem* child );
     PackageTreeItem* child( int row );
     int childCount() const;
-    int columnCount() const;
     QVariant data( int column ) const override;
     int row() const;
 
@@ -78,11 +84,11 @@ public:
     void setSelected( Qt::CheckState isSelected );
     void setChildrenSelected( Qt::CheckState isSelected );
     int type() const override;
+
 private:
     PackageTreeItem* m_parentItem;
-    QList<PackageTreeItem*> m_childItems;
+    QList< PackageTreeItem* > m_childItems;
     ItemData m_data;
-    const int m_columns = 2; // Name, description
 };
 
-#endif // PACKAGETREEITEM_H
+#endif  // PACKAGETREEITEM_H
