@@ -53,7 +53,6 @@ PackageChooserPage::PackageChooserPage( PackageChooserMode mode, QWidget* parent
     }
 
     ui->products->setMinimumWidth( 10 * CalamaresUtils::defaultFontHeight() );
-
 }
 
 /** @brief size the given @p pixmap to @p size
@@ -140,6 +139,16 @@ PackageChooserPage::setModel( QAbstractItemModel* model )
              &PackageChooserPage::updateLabels );
 }
 
+void
+PackageChooserPage::setSelection( const QModelIndex& index )
+{
+    if ( index.isValid() )
+    {
+        ui->products->selectionModel()->select( index, QItemSelectionModel::Select );
+        currentChanged( index );
+    }
+}
+
 bool
 PackageChooserPage::hasSelection() const
 {
