@@ -66,18 +66,18 @@ private:
 
 namespace Calamares
 {
-    /** @brief Returns the row number of boot-loader @p path (e.g. /dev/sda)
-     *
-     * Assuming the @p model is a BootLoaderModel, will return a row number
-     * in the model. Returns -1 otherwise.
-     */
-    int findBootloader( const QAbstractItemModel* model, const QString& path );
+/** @brief Returns the row number of boot-loader @p path (e.g. /dev/sda)
+ *
+ * Assuming the @p model is a BootLoaderModel, will return a row number
+ * in the model. Returns -1 otherwise.
+ */
+int findBootloader( const QAbstractItemModel* model, const QString& path );
 
-    /** @brief Tries to set @p path as selected item in @p combo
-     *
-     * Matches a boot-loader install path (e.g. /dev/sda) with a model
-     * row and sets that as the current row.
-     */
-    void restoreSelectedBootLoader( QComboBox& combo, const QString& path );
-}  // namespace
+/** @brief Tries to set @p path as selected item in @p combo
+ *
+ * Matches a boot-loader install path (e.g. /dev/sda) with a model
+ * row and sets that as the current row.
+ */
+void restoreSelectedBootLoader( QComboBox& combo, const QString& path );
+}  // namespace Calamares
 #endif /* BOOTLOADERMODEL_H */
