@@ -1,7 +1,7 @@
 /* === This file is part of Calamares - <https://github.com/calamares> ===
  *
  *   Copyright 2015-2016, Teo Mrnjavac <teo@kde.org>
- *   Copyright 2018, Adriaan de Groot <groot@kde.org>
+ *   Copyright 2018-2019, Adriaan de Groot <groot@kde.org>
  *
  *   Calamares is free software: you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -20,23 +20,24 @@
 #include "DeviceList.h"
 
 #include "PartitionCoreModule.h"
-
 #include "core/DeviceModel.h"
 #include "core/KPMHelpers.h"
-#include "core/PartitionIterator.h"
+
+#include "GlobalStorage.h"
+#include "JobQueue.h"
+#include "partition/PartitionIterator.h"
+#include "utils/Logger.h"
 
 #include <kpmcore/backend/corebackend.h>
 #include <kpmcore/backend/corebackendmanager.h>
 #include <kpmcore/core/device.h>
 #include <kpmcore/core/partition.h>
 
-#include <utils/Logger.h>
-#include <JobQueue.h>
-#include <GlobalStorage.h>
-
 #include <QProcess>
 #include <QTemporaryDir>
 
+using CalamaresUtils::Partition::PartitionIterator;
+
 namespace PartUtils
 {
 
@@ -49,35 +50,43 @@ hasRootPartition( Device* device )
 {
     for ( auto it = PartitionIterator::begin( device ); it != PartitionIterator::end( device ); ++it )
         if ( ( *it )->mountPoint() == "/" )
+        {
             return true;
+        }
     return false;
 }
 
+static bool
+blkIdCheckIso9660( const QString& path )
+{
+    QProcess blkid;
+    blkid.start( "blkid", { path } );
+    blkid.waitForFinished();
+    QString output = QString::fromLocal8Bit( blkid.readAllStandardOutput() );
+    return output.contains( "iso9660" );
+}
+
 static bool
 isIso9660( const Device* device )
 {
-    QString path = device->deviceNode();
+    const QString path = device->deviceNode();
     if ( path.isEmpty() )
+    {
         return false;
-
-    QProcess blkid;
-    blkid.start( "blkid", { path } );
-    blkid.waitForFinished();
-    QString output = QString::fromLocal8Bit( blkid.readAllStandardOutput() );
-    if ( output.contains( "iso9660" ) )
+    }
+    if ( blkIdCheckIso9660( path ) )
+    {
         return true;
+    }
 
-    if ( device->partitionTable() &&
-            !device->partitionTable()->children().isEmpty() )
+    if ( device->partitionTable() && !device->partitionTable()->children().isEmpty() )
     {
         for ( const Partition* partition : device->partitionTable()->children() )
         {
-            path = partition->partitionPath();
-            blkid.start( "blkid", { path } );
-            blkid.waitForFinished();
-            QString output = QString::fromLocal8Bit( blkid.readAllStandardOutput() );
-            if ( output.contains( "iso9660" ) )
+            if ( blkIdCheckIso9660( partition->partitionPath() ) )
+            {
                 return true;
+            }
         }
     }
     return false;
@@ -85,7 +94,7 @@ isIso9660( const Device* device )
 
 
 static inline QDebug&
-operator <<( QDebug& s, QList< Device* >::iterator& it )
+operator<<( QDebug& s, QList< Device* >::iterator& it )
 {
     s << ( ( *it ) ? ( *it )->deviceNode() : QString( "<null device>" ) );
     return s;
@@ -94,7 +103,7 @@ operator <<( QDebug& s, QList< Device* >::iterator& it )
 using DeviceList = QList< Device* >;
 
 static inline DeviceList::iterator
-erase(DeviceList& l, DeviceList::iterator& it)
+erase( DeviceList& l, DeviceList::iterator& it )
 {
     Device* p = *it;
     auto r = l.erase( it );
@@ -102,46 +111,58 @@ erase(DeviceList& l, DeviceList::iterator& it)
     return r;
 }
 
-QList< Device* > getDevices( DeviceType which, qint64 minimumSize )
+QList< Device* >
+getDevices( DeviceType which, qint64 minimumSize )
 {
-    bool writableOnly = (which == DeviceType::WritableOnly);
+    bool writableOnly = ( which == DeviceType::WritableOnly );
 
     CoreBackend* backend = CoreBackendManager::self()->backend();
-    DeviceList devices = backend->scanDevices( true );
+#if defined( WITH_KPMCORE4API )
+    DeviceList devices = backend->scanDevices( /* not includeReadOnly, not includeLoopback */ ScanFlag( 0 ) );
+#else
+    DeviceList devices = backend->scanDevices( /* excludeReadOnly */ true );
+#endif
 
+#ifdef DEBUG_PARTITION_UNSAFE
+    cWarning() << "Allowing unsafe partitioning choices." << devices.count() << "candidates.";
+#ifdef DEBUG_PARTITION_LAME
+    cDebug() << Logger::SubEntry << "it has been lamed, and will fail.";
+#endif
+#else
     cDebug() << "Removing unsuitable devices:" << devices.count() << "candidates.";
 
     // Remove the device which contains / from the list
     for ( DeviceList::iterator it = devices.begin(); it != devices.end(); )
         if ( !( *it ) )
         {
-            cDebug() << "  .. Skipping nullptr device";
-            it = erase( devices, it);
+            cDebug() << Logger::SubEntry << "Skipping nullptr device";
+            it = erase( devices, it );
         }
-        else if ( ( *it )->deviceNode().startsWith( "/dev/zram" )
-        )
+        else if ( ( *it )->deviceNode().startsWith( "/dev/zram" ) )
         {
-            cDebug() << "  .. Removing zram" << it;
+            cDebug() << Logger::SubEntry << "Removing zram" << it;
             it = erase( devices, it );
-
         }
         else if ( writableOnly && hasRootPartition( *it ) )
         {
-            cDebug() << "  .. Removing device with root filesystem (/) on it" << it;
+            cDebug() << Logger::SubEntry << "Removing device with root filesystem (/) on it" << it;
             it = erase( devices, it );
         }
         else if ( writableOnly && isIso9660( *it ) )
         {
-            cDebug() << "  .. Removing device with iso9660 filesystem (probably a CD) on it" << it;
+            cDebug() << Logger::SubEntry << "Removing device with iso9660 filesystem (probably a CD) on it" << it;
             it = erase( devices, it );
         }
-        else if ( (minimumSize >= 0) && !( (*it)->capacity() > minimumSize ) )
+        else if ( ( minimumSize >= 0 ) && !( ( *it )->capacity() > minimumSize ) )
         {
-            cDebug() << "  .. Removing too-small" << it;
+            cDebug() << Logger::SubEntry << "Removing too-small" << it;
             it = erase( devices, it );
         }
         else
+        {
             ++it;
+        }
+#endif
 
     return devices;
 }
