@@ -2,6 +2,7 @@
  *
  *   Copyright 2014, Aurélien Gâteau <agateau@kde.org>
  *   Copyright 2014, Teo Mrnjavac <teo@kde.org>
+ *   Copyright 2019, Adriaan de Groot <groot@kde.org>
  *
  *   Calamares is free software: you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -30,28 +31,32 @@
 #include <KFormat>
 
 #include <QIcon>
+#include <QStandardItemModel>
 
 // STL
 #include <algorithm>
 
+static void
+sortDevices( DeviceModel::DeviceList& l )
+{
+    std::sort( l.begin(), l.end(), []( const Device* dev1, const Device* dev2 ) {
+        return dev1->deviceNode() < dev2->deviceNode();
+    } );
+}
+
 DeviceModel::DeviceModel( QObject* parent )
     : QAbstractListModel( parent )
 {
 }
 
-DeviceModel::~DeviceModel()
-{
-}
+DeviceModel::~DeviceModel() {}
 
 void
-DeviceModel::init( const QList< Device* >& devices )
+DeviceModel::init( const DeviceList& devices )
 {
     beginResetModel();
     m_devices = devices;
-    std::sort( m_devices.begin(), m_devices.end(), []( const Device* dev1, const Device* dev2 )
-    {
-        return dev1->deviceNode() < dev2->deviceNode();
-    } );
+    sortDevices( m_devices );
     endResetModel();
 }
 
@@ -66,7 +71,9 @@ DeviceModel::data( const QModelIndex& index, int role ) const
 {
     int row = index.row();
     if ( row < 0 || row >= m_devices.count() )
+    {
         return QVariant();
+    }
 
     Device* device = m_devices.at( row );
 
@@ -75,17 +82,33 @@ DeviceModel::data( const QModelIndex& index, int role ) const
     case Qt::DisplayRole:
     case Qt::ToolTipRole:
         if ( device->name().isEmpty() )
+        {
             return device->deviceNode();
+        }
         else
-            return tr( "%1 - %2 (%3)" )
-                   .arg( device->name() )
-                   .arg( KFormat().formatByteSize( device->capacity() ) )
-                   .arg( device->deviceNode() );
+        {
+            if ( device->logicalSize() >= 0 && device->totalLogical() >= 0 )
+            {
+                //: device[name] - size[number] (device-node[name])
+                return tr( "%1 - %2 (%3)" )
+                    .arg( device->name() )
+                    .arg( KFormat().formatByteSize( device->capacity() ) )
+                    .arg( device->deviceNode() );
+            }
+            else
+            {
+                // Newly LVM VGs don't have capacity property yet (i.e.
+                // always has 1B capacity), so don't show it for a while.
+                //
+                //: device[name] - (device-node[name])
+                return tr( "%1 - (%2)" ).arg( device->name() ).arg( device->deviceNode() );
+            }
+        }
     case Qt::DecorationRole:
-        return CalamaresUtils::defaultPixmap( CalamaresUtils::PartitionDisk,
-                                              CalamaresUtils::Original,
-                                              QSize( CalamaresUtils::defaultIconSize().width() * 3,
-                                                     CalamaresUtils::defaultIconSize().height() * 3 ) );
+        return CalamaresUtils::defaultPixmap(
+            CalamaresUtils::PartitionDisk,
+            CalamaresUtils::Original,
+            QSize( CalamaresUtils::defaultIconSize().width() * 3, CalamaresUtils::defaultIconSize().height() * 3 ) );
     default:
         return QVariant();
     }
@@ -97,7 +120,9 @@ DeviceModel::deviceForIndex( const QModelIndex& index ) const
 {
     int row = index.row();
     if ( row < 0 || row >= m_devices.count() )
+    {
         return nullptr;
+    }
     return m_devices.at( row );
 }
 
@@ -110,9 +135,29 @@ DeviceModel::swapDevice( Device* oldDevice, Device* newDevice )
 
     int indexOfOldDevice = m_devices.indexOf( oldDevice );
     if ( indexOfOldDevice < 0 )
+    {
         return;
+    }
 
     m_devices[ indexOfOldDevice ] = newDevice;
 
     emit dataChanged( index( indexOfOldDevice ), index( indexOfOldDevice ) );
 }
+
+void
+DeviceModel::addDevice( Device* device )
+{
+    beginResetModel();
+    m_devices << device;
+    sortDevices( m_devices );
+    endResetModel();
+}
+
+void
+DeviceModel::removeDevice( Device* device )
+{
+    beginResetModel();
+    m_devices.removeAll( device );
+    sortDevices( m_devices );
+    endResetModel();
+}
