@@ -34,13 +34,13 @@ class Partition;
 class PartitionNode;
 class PartitionRole;
 
-#ifdef WITH_KPMCORE331API
-#define KPM_PARTITION_FLAG(x) PartitionTable::Flag::x
-#define KPM_PARTITION_STATE(x) Partition::State::x
+#if defined( WITH_KPMCORE4API )
+#define KPM_PARTITION_FLAG( x ) PartitionTable::Flag::x
+#define KPM_PARTITION_STATE( x ) Partition::State::x
 #define KPM_PARTITION_FLAG_ESP PartitionTable::Flag::Boot
 #else
-#define KPM_PARTITION_FLAG(x) PartitionTable::Flag##x
-#define KPM_PARTITION_STATE(x) Partition::State##x
+#define KPM_PARTITION_FLAG( x ) PartitionTable::Flag##x
+#define KPM_PARTITION_STATE( x ) Partition::State##x
 #define KPM_PARTITION_FLAG_ESP PartitionTable::FlagEsp
 #endif
 
@@ -50,46 +50,12 @@ class PartitionRole;
 namespace KPMHelpers
 {
 
-/**
- * Thin wrapper on top of CoreBackendManager. Hides things like initializing the
- * Config instance or instantiating the backend.
- *
- * Initialize PartitionManager Config object and load a PartitionManager
- * backend. It loads the "libparted" plugin by default, but this can be
- * overloaded by settings the environment variable KPMCORE_BACKEND. Setting it to
- * "dummy" will load the dummy plugin instead.
- *
- * @return true if initialization was successful.
- */
-bool initKPMcore();
-
-bool isPartitionFreeSpace( Partition* );
-
-/**
- * Returns true if the partition is planned to be created by the installer as
- * opposed to already existing on the disk.
- */
-bool isPartitionNew( Partition* );
-
 /**
  * Iterates on all devices and return the first partition which is associated
  * with mountPoint. This uses PartitionInfo::mountPoint(), not Partition::mountPoint()
  */
 Partition* findPartitionByMountPoint( const QList< Device* >& devices, const QString& mountPoint );
 
-/**
- * Iterates on all devices and partitions and returns a pointer to the Partition object
- * for the given path, or nullptr if a Partition for the given path cannot be found.
- */
-Partition* findPartitionByPath( const QList< Device* >& devices, const QString& path );
-
-/**
- * Iterates on all devices and partitions and returns a list of pointers to the Partition
- * objects that satisfy the conditions defined in the criterion function.
- */
-QList< Partition* > findPartitions( const QList< Device* >& devices,
-                                    std::function< bool ( Partition* ) > criterionFunction );
-
 /**
  * Helper function to create a new Partition object (does not create anything
  * on the disk) associated with a FileSystem.
@@ -113,7 +79,6 @@ Partition* createNewEncryptedPartition( PartitionNode* parent,
 
 Partition* clonePartition( Device* device, Partition* partition );
 
-QString prettyNameForFileSystemType( FileSystem::Type t );
-}
+}  // namespace KPMHelpers
 
 #endif /* KPMHELPERS_H */
