@@ -2,6 +2,7 @@
  *
  *   Copyright 2014, Aurélien Gâteau <agateau@kde.org>
  *   Copyright 2016, Teo Mrnjavac <teo@kde.org>
+ *   Copyright 2018, 2020, Adriaan de Groot <groot@kde.org>
  *
  *   Flags handling originally from KDE Partition Manager,
  *   Copyright 2008-2009, Volker Lanz <vl@fidra.de>
@@ -21,32 +22,32 @@
  *   along with Calamares. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include <gui/EditExistingPartitionDialog.h>
+#include "EditExistingPartitionDialog.h"
+#include "ui_EditExistingPartitionDialog.h"
 
-#include <core/ColorUtils.h>
-#include <core/PartitionCoreModule.h>
-#include <core/PartitionInfo.h>
+#include "core/ColorUtils.h"
+#include "core/PartitionCoreModule.h"
+#include "core/PartitionInfo.h"
 #include "core/PartUtils.h"
-#include <core/KPMHelpers.h>
 #include "gui/PartitionDialogHelpers.h"
-#include <gui/PartitionSizeController.h>
+#include "gui/PartitionSizeController.h"
 
-#include <ui_EditExistingPartitionDialog.h>
-
-#include <utils/Logger.h>
 #include "GlobalStorage.h"
 #include "JobQueue.h"
+#include "partition/FileSystem.h"
+#include "utils/Logger.h"
 
-// KPMcore
 #include <kpmcore/core/device.h>
 #include <kpmcore/core/partition.h>
 #include <kpmcore/fs/filesystemfactory.h>
 
-// Qt
 #include <QComboBox>
 #include <QDir>
 #include <QPushButton>
 
+using CalamaresUtils::Partition::untranslatedFS;
+using CalamaresUtils::Partition::userVisibleFS;
+
 EditExistingPartitionDialog::EditExistingPartitionDialog( Device* device, Partition* partition, const QStringList& usedMountPoints, QWidget* parentWidget )
     : QDialog( parentWidget )
     , m_ui( new Ui_EditExistingPartitionDialog )
@@ -76,7 +77,7 @@ EditExistingPartitionDialog::EditExistingPartitionDialog( Device* device, Partit
         m_ui->fileSystemComboBox->setEnabled( doFormat );
 
         if ( !doFormat )
-            m_ui->fileSystemComboBox->setCurrentText( m_partition->fileSystem().name() );
+            m_ui->fileSystemComboBox->setCurrentText( userVisibleFS( m_partition->fileSystem() ) );
 
         updateMountPointPicker();
     } );
@@ -92,16 +93,25 @@ EditExistingPartitionDialog::EditExistingPartitionDialog( Device* device, Partit
     for ( auto fs : FileSystemFactory::map() )
     {
         if ( fs->supportCreate() != FileSystem::cmdSupportNone && fs->type() != FileSystem::Extended )
-            fsNames << fs->name();
+            fsNames << userVisibleFS( fs ); // For the combo box
     }
     m_ui->fileSystemComboBox->addItems( fsNames );
 
-    if ( fsNames.contains( m_partition->fileSystem().name() ) )
-        m_ui->fileSystemComboBox->setCurrentText( m_partition->fileSystem().name() );
+    FileSystem::Type defaultFSType;
+    QString untranslatedFSName = PartUtils::findFS(
+                                         Calamares::JobQueue::instance()->
+                                         globalStorage()->
+                                         value( "defaultFileSystemType" ).toString(), &defaultFSType );
+    if ( defaultFSType == FileSystem::Type::Unknown )
+    {
+        defaultFSType = FileSystem::Type::Ext4;
+    }
+
+    QString thisFSNameForUser = userVisibleFS( m_partition->fileSystem() );
+    if ( fsNames.contains( thisFSNameForUser ) )
+        m_ui->fileSystemComboBox->setCurrentText( thisFSNameForUser );
     else
-        m_ui->fileSystemComboBox->setCurrentText( Calamares::JobQueue::instance()->
-                                                      globalStorage()->
-                                                      value( "defaultFileSystemType" ).toString() );
+        m_ui->fileSystemComboBox->setCurrentText( FileSystem::nameForType( defaultFSType ) );
 
     m_ui->fileSystemLabel->setEnabled( m_ui->formatRadioButton->isChecked() );
     m_ui->fileSystemComboBox->setEnabled( m_ui->formatRadioButton->isChecked() );
