@@ -40,11 +40,13 @@
 #include "ui_PartitionPage.h"
 #include "ui_CreatePartitionTableDialog.h"
 
+#include "GlobalStorage.h"
+#include "JobQueue.h"
+#include "partition/PartitionQuery.h"
 #include "utils/Logger.h"
 #include "utils/Retranslator.h"
+
 #include "Branding.h"
-#include "JobQueue.h"
-#include "GlobalStorage.h"
 
 // KPMcore
 #include <kpmcore/core/device.h>
@@ -132,7 +134,7 @@ PartitionPage::updateButtons()
         Q_ASSERT( model );
         Partition* partition = model->partitionForIndex( index );
         Q_ASSERT( partition );
-        bool isFree = KPMHelpers::isPartitionFreeSpace( partition );
+        bool isFree = CalamaresUtils::Partition::isPartitionFreeSpace( partition );
         bool isExtended = partition->roles().has( PartitionRole::Extended );
 
         bool isInVG = m_core->isInVG( partition );
@@ -219,7 +221,7 @@ PartitionPage::onNewPartitionTableClicked()
         m_core->createPartitionTable( device, type );
     }
     delete dlg;
-    // PartionModelReset isn't emmited after createPartitionTable, so we have to manually update
+    // PartionModelReset isn't emitted after createPartitionTable, so we have to manually update
     // the bootLoader index after the reset.
     updateBootLoaderIndex();
 }
@@ -392,7 +394,7 @@ PartitionPage::onEditClicked()
     Partition* partition = model->partitionForIndex( index );
     Q_ASSERT( partition );
 
-    if ( KPMHelpers::isPartitionNew( partition ) )
+    if ( CalamaresUtils::Partition::isPartitionNew( partition ) )
         updatePartitionToCreate( model->device(), partition );
     else
         editExistingPartition( model->device(), partition );
@@ -452,7 +454,7 @@ PartitionPage::onPartitionViewActivated()
     // but I don't expect there will be other occurences of triggering the same
     // action from multiple UI elements in this page, so it does not feel worth
     // the price.
-    if ( KPMHelpers::isPartitionFreeSpace( partition ) )
+    if ( CalamaresUtils::Partition::isPartitionFreeSpace( partition ) )
         m_ui->createButton->click();
     else
         m_ui->editButton->click();
@@ -511,45 +513,10 @@ PartitionPage::updateSelectedBootLoaderIndex()
     cDebug() << "Selected bootloader index" << m_lastSelectedBootLoaderIndex;
 }
 
-int
-findBootloader( const QAbstractItemModel* model, const QString& path )
-{
-    for ( int i = 0; i < model->rowCount(); ++i)
-    {
-        const auto index = model->index( i, 0, QModelIndex() );
-        if ( !index.isValid() )
-            continue;
-        QVariant var = model->data( index, BootLoaderModel::BootLoaderPathRole );
-        if ( var.isValid() && var.toString() == path )
-            return i;
-    }
-
-    return -1;
-}
-
 void
 PartitionPage::restoreSelectedBootLoader()
 {
-    const auto* model = m_ui->bootLoaderComboBox->model();
-    if ( model->rowCount() < 1 )
-    {
-        cDebug() << "No items in BootLoaderModel";
-        return;
-    }
-
-    int r = -1;
-    if ( m_core->bootLoaderInstallPath().isEmpty() )
-    {
-        m_ui->bootLoaderComboBox->setCurrentIndex( 0 );
-    }
-    else if ( (r = findBootloader( model, m_core->bootLoaderInstallPath() )) >= 0 )
-    {
-        m_ui->bootLoaderComboBox->setCurrentIndex( r );
-    }
-    else
-    {
-        m_ui->bootLoaderComboBox->setCurrentIndex( 0 );
-    }
+    Calamares::restoreSelectedBootLoader( *(m_ui->bootLoaderComboBox), m_core->bootLoaderInstallPath() );
 }
 
 
@@ -564,7 +531,7 @@ PartitionPage::updateFromCurrentDevice()
 
     QAbstractItemModel* oldModel = m_ui->partitionTreeView->model();
     if ( oldModel )
-        disconnect( oldModel, 0, this, 0 );
+        disconnect( oldModel, nullptr, this, nullptr );
 
     PartitionModel* model = m_core->partitionModelForDevice( device );
     m_ui->partitionBarsView->setModel( model );
