@@ -1,4 +1,4 @@
-/* === This file is part of Calamares - <http://github.com/calamares> ===
+/* === This file is part of Calamares - <https://github.com/calamares> ===
  *
  *   Copyright 2014-2015, Teo Mrnjavac <teo@kde.org>
  *
@@ -19,7 +19,7 @@
 #ifndef CLEARMOUNTSJOB_H
 #define CLEARMOUNTSJOB_H
 
-#include <Job.h>
+#include "Job.h"
 
 class Device;
 
