@@ -20,6 +20,7 @@
 #define DEACTIVATEVOLUMEGROUPJOB_H
 
 #include "Job.h"
+#include "partition/KPMManager.h"
 
 class LvmDevice;
 
@@ -35,6 +36,7 @@ public:
     Calamares::JobResult exec() override;
 
 private:
+    CalamaresUtils::Partition::KPMManager m_kpmcore;
     LvmDevice* m_device;
 };
 
