@@ -1,6 +1,7 @@
 /* === This file is part of Calamares - <https://github.com/calamares> ===
  *
  *   Copyright 2016, Teo Mrnjavac <teo@kde.org>
+ *   Copyright 2020, Adriaan de Groot <groot@kde.org>
  *
  *   Based on the SetPartFlagsJob class from KDE Partition Manager,
  *   Copyright 2008, 2010, Volker Lanz <vl@fidra.de>
@@ -21,17 +22,19 @@
 
 #include "SetPartitionFlagsJob.h"
 
+#include "partition/FileSystem.h"
 #include "utils/Logger.h"
 #include "utils/Units.h"
 
-// KPMcore
-#include <core/device.h>
-#include <core/partition.h>
-#include <fs/filesystem.h>
-#include <ops/setpartflagsoperation.h>
-#include <util/report.h>
+#include <kpmcore/core/device.h>
+#include <kpmcore/core/partition.h>
+#include <kpmcore/fs/filesystem.h>
+#include <kpmcore/ops/setpartflagsoperation.h>
+#include <kpmcore/util/report.h>
 
 using CalamaresUtils::BytesToMiB;
+using CalamaresUtils::Partition::untranslatedFS;
+using CalamaresUtils::Partition::userVisibleFS;
 
 SetPartFlagsJob::SetPartFlagsJob( Device* device,
                                   Partition* partition,
@@ -48,10 +51,11 @@ SetPartFlagsJob::prettyName() const
     if ( !partition()->partitionPath().isEmpty() )
         return tr( "Set flags on partition %1." ).arg( partition()->partitionPath() );
 
-    if ( !partition()->fileSystem().name().isEmpty() )
+    QString fsNameForUser = userVisibleFS( partition()->fileSystem() );
+    if ( !fsNameForUser.isEmpty() )
         return tr( "Set flags on %1MiB %2 partition." )
                .arg( BytesToMiB( partition()->capacity() ) )
-               .arg( partition()->fileSystem().name() );
+               .arg( fsNameForUser );
 
     return tr( "Set flags on new partition." );
 }
@@ -67,10 +71,11 @@ SetPartFlagsJob::prettyDescription() const
             return tr( "Clear flags on partition <strong>%1</strong>." )
                    .arg( partition()->partitionPath() );
 
-        if ( !partition()->fileSystem().name().isEmpty() )
+        QString fsNameForUser = userVisibleFS( partition()->fileSystem() );
+        if ( !fsNameForUser.isEmpty() )
             return tr( "Clear flags on %1MiB <strong>%2</strong> partition." )
                    .arg( BytesToMiB( partition()->capacity() ) )
-                   .arg( partition()->fileSystem().name() );
+                   .arg( fsNameForUser );
 
         return tr( "Clear flags on new partition." );
     }
@@ -81,11 +86,12 @@ SetPartFlagsJob::prettyDescription() const
                .arg( partition()->partitionPath() )
                .arg( flagsList.join( ", " ) );
 
-    if ( !partition()->fileSystem().name().isEmpty() )
+    QString fsNameForUser = userVisibleFS( partition()->fileSystem() );
+    if ( !fsNameForUser.isEmpty() )
         return tr( "Flag %1MiB <strong>%2</strong> partition as "
                    "<strong>%3</strong>." )
                .arg( BytesToMiB( partition()->capacity() ) )
-               .arg( partition()->fileSystem().name() )
+               .arg( fsNameForUser )
                .arg( flagsList.join( ", " ) );
 
     return tr( "Flag new partition as <strong>%1</strong>." )
@@ -103,10 +109,11 @@ SetPartFlagsJob::prettyStatusMessage() const
             return tr( "Clearing flags on partition <strong>%1</strong>." )
                    .arg( partition()->partitionPath() );
 
-        if ( !partition()->fileSystem().name().isEmpty() )
+        QString fsNameForUser = userVisibleFS( partition()->fileSystem() );
+        if ( !fsNameForUser.isEmpty() )
             return tr( "Clearing flags on %1MiB <strong>%2</strong> partition." )
                    .arg( BytesToMiB( partition()->capacity() ) )
-                   .arg( partition()->fileSystem().name() );
+                   .arg( fsNameForUser );
 
         return tr( "Clearing flags on new partition." );
     }
@@ -117,11 +124,12 @@ SetPartFlagsJob::prettyStatusMessage() const
                .arg( partition()->partitionPath() )
                .arg( flagsList.join( ", " ) );
 
-    if ( !partition()->fileSystem().name().isEmpty() )
+    QString fsNameForUser = userVisibleFS( partition()->fileSystem() );
+    if ( !fsNameForUser.isEmpty() )
         return tr( "Setting flags <strong>%3</strong> on "
                    "%1MiB <strong>%2</strong> partition." )
                .arg( BytesToMiB( partition()->capacity() ) )
-               .arg( partition()->fileSystem().name() )
+               .arg( fsNameForUser )
                .arg( flagsList.join( ", " ) );
 
     return tr( "Setting flags <strong>%1</strong> on new partition." )
