@@ -22,7 +22,7 @@
 #ifndef SETPARTITIONFLAGSJOB_H
 #define SETPARTITIONFLAGSJOB_H
 
-#include <jobs/PartitionJob.h>
+#include "PartitionJob.h"
 
 #include <kpmcore/core/partitiontable.h>
 
