@@ -21,7 +21,7 @@
 
 #include <utils/PluginFactory.h>
 #include <viewpages/ViewStep.h>
-#include <PluginDllMacro.h>
+#include <DllMacro.h>
 
 #include <QObject>
 #include <QUrl>
