@@ -21,7 +21,7 @@
 
 #include "TrackingType.h"
 
-#include <PluginDllMacro.h>
+#include <DllMacro.h>
 #include <utils/PluginFactory.h>
 #include <viewpages/ViewStep.h>
 
