@@ -1,4 +1,4 @@
-/* === This file is part of Calamares - <http://github.com/calamares> ===
+/* === This file is part of Calamares - <https://github.com/calamares> ===
  *
  *   Copyright 2017, Adriaan de Groot <groot@kde.org>
  *
@@ -24,13 +24,9 @@
 
 QTEST_GUILESS_MAIN( PasswordTests )
 
-PasswordTests::PasswordTests()
-{
-}
+PasswordTests::PasswordTests() {}
 
-PasswordTests::~PasswordTests()
-{
-}
+PasswordTests::~PasswordTests() {}
 
 void
 PasswordTests::initTestCase()
@@ -41,7 +37,7 @@ void
 PasswordTests::testSalt()
 {
     QString s = SetPasswordJob::make_salt( 8 );
-    QCOMPARE( s.length(), 4 + 8 ); // 8 salt chars, plus $6$, plus trailing $
+    QCOMPARE( s.length(), 4 + 8 );  // 8 salt chars, plus $6$, plus trailing $
     QVERIFY( s.startsWith( "$6$" ) );
     QVERIFY( s.endsWith( '$' ) );
     qDebug() << "Obtained salt" << s;
