@@ -2,6 +2,7 @@
  *
  *   Copyright 2014, Rohan Garg <rohan@kde.org>
  *   Copyright 2015, Teo Mrnjavac <teo@kde.org>
+ *   Copyright 2020, Adriaan de Groot <groot@kde.org>
  *
  *   Calamares is free software: you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -26,7 +27,17 @@ class SetHostNameJob : public Calamares::Job
 {
     Q_OBJECT
 public:
-    SetHostNameJob( const QString& hostname );
+    enum Action
+    {
+        None = 0x0,
+        EtcHostname = 0x1,  // Write to /etc/hostname directly
+        SystemdHostname = 0x2,  // Set via hostnamed(1)
+        WriteEtcHosts = 0x4  // Write /etc/hosts (127.0.1.1 is this host)
+    };
+    Q_DECLARE_FLAGS( Actions, Action )
+
+
+    SetHostNameJob( const QString& hostname, Actions a );
     QString prettyName() const override;
     QString prettyDescription() const override;
     QString prettyStatusMessage() const override;
@@ -34,7 +45,9 @@ public:
 
 private:
     const QString m_hostname;
+    const Actions m_actions;
 };
 
+Q_DECLARE_OPERATORS_FOR_FLAGS( SetHostNameJob::Actions )
 
 #endif  // SETHOSTNAMEJOB_CPP_H
