@@ -26,7 +26,7 @@
 #include <utils/PluginFactory.h>
 #include <viewpages/ViewStep.h>
 
-#include <PluginDllMacro.h>
+#include <DllMacro.h>
 
 #include <QVariantMap>
 
