@@ -33,13 +33,16 @@
 #include <QFutureWatcher>
 #include <QVariant>
 
-CALAMARES_PLUGIN_FACTORY_DEFINITION( WelcomeViewStepFactory, registerPlugin<WelcomeViewStep>(); )
+CALAMARES_PLUGIN_FACTORY_DEFINITION( WelcomeViewStepFactory, registerPlugin< WelcomeViewStep >(); )
 
 WelcomeViewStep::WelcomeViewStep( QObject* parent )
     : Calamares::ViewStep( parent )
     , m_requirementsChecker( new GeneralRequirements( this ) )
 {
-    connect( Calamares::ModuleManager::instance(), &Calamares::ModuleManager::requirementsComplete, this, &WelcomeViewStep::nextStatusChanged );
+    connect( Calamares::ModuleManager::instance(),
+             &Calamares::ModuleManager::requirementsComplete,
+             this,
+             &WelcomeViewStep::nextStatusChanged );
     m_widget = new WelcomePage();
 }
 
@@ -47,7 +50,9 @@ WelcomeViewStep::WelcomeViewStep( QObject* parent )
 WelcomeViewStep::~WelcomeViewStep()
 {
     if ( m_widget && m_widget->parent() == nullptr )
+    {
         m_widget->deleteLater();
+    }
 }
 
 
@@ -100,23 +105,60 @@ WelcomeViewStep::jobs() const
 }
 
 
+/** @brief Look up a URL for a button
+ *
+ * Looks up @p key in @p map; if it is a *boolean* value, then
+ * assume an old-style configuration, and fetch the string from
+ * the branding settings @p e. If it is a string, not a boolean,
+ * use it as-is. If not found, or a weird type, returns empty.
+ *
+ * This allows switching the showKnownIssuesUrl and similar settings
+ * in welcome.conf from a boolean (deferring to branding) to an
+ * actual string for immediate use. Empty strings, as well as
+ * "false" as a setting, will hide the buttons as before.
+ */
+static QString
+jobOrBrandingSetting( Calamares::Branding::StringEntry e, const QVariantMap& map, const QString& key )
+{
+    if ( !map.contains( key ) )
+    {
+        return QString();
+    }
+    auto v = map.value( key );
+    if ( v.type() == QVariant::Bool )
+    {
+        return v.toBool() ? ( *e ) : QString();
+    }
+    if ( v.type() == QVariant::String )
+    {
+        return v.toString();
+    }
+
+    return QString();
+}
+
 void
 WelcomeViewStep::setConfigurationMap( const QVariantMap& configurationMap )
 {
-    bool showSupportUrl = CalamaresUtils::getBool( configurationMap, "showSupportUrl", false );
-    bool showKnownIssuesUrl = CalamaresUtils::getBool( configurationMap, "showKnownIssuesUrl", false );
-    bool showReleaseNotesUrl = CalamaresUtils::getBool( configurationMap, "showReleaseNotesUrl", false );
+    using Calamares::Branding;
 
-    m_widget->setUpLinks( showSupportUrl,
-                          showKnownIssuesUrl,
-                          showReleaseNotesUrl );
+    m_widget->setupButton( WelcomePage::Button::Support,
+                           jobOrBrandingSetting( Branding::SupportUrl, configurationMap, "showSupportUrl" ) );
+    m_widget->setupButton( WelcomePage::Button::KnownIssues,
+                           jobOrBrandingSetting( Branding::KnownIssuesUrl, configurationMap, "showKnownIssuesUrl" ) );
+    m_widget->setupButton( WelcomePage::Button::ReleaseNotes,
+                           jobOrBrandingSetting( Branding::ReleaseNotesUrl, configurationMap, "showReleaseNotesUrl" ) );
+    m_widget->setupButton( WelcomePage::Button::Donate,
+                           CalamaresUtils::getString( configurationMap, "showDonateUrl" ) );
 
-    if ( configurationMap.contains( "requirements" ) &&
-         configurationMap.value( "requirements" ).type() == QVariant::Map )
+    if ( configurationMap.contains( "requirements" )
+         && configurationMap.value( "requirements" ).type() == QVariant::Map )
+    {
         m_requirementsChecker->setConfigurationMap( configurationMap.value( "requirements" ).toMap() );
+    }
     else
         cWarning() << "no valid requirements map found in welcome "
-                    "module configuration.";
+                      "module configuration.";
 
     bool ok = false;
     QVariantMap geoip = CalamaresUtils::getSubMap( configurationMap, "geoip", ok );
@@ -124,15 +166,13 @@ WelcomeViewStep::setConfigurationMap( const QVariantMap& configurationMap )
     {
         using FWString = QFutureWatcher< QString >;
 
-        auto* handler = new CalamaresUtils::GeoIP::Handler(
-            CalamaresUtils::getString( geoip, "style" ),
-            CalamaresUtils::getString( geoip, "url" ),
-            CalamaresUtils::getString( geoip, "selector" ) );
+        auto* handler = new CalamaresUtils::GeoIP::Handler( CalamaresUtils::getString( geoip, "style" ),
+                                                            CalamaresUtils::getString( geoip, "url" ),
+                                                            CalamaresUtils::getString( geoip, "selector" ) );
         if ( handler->type() != CalamaresUtils::GeoIP::Handler::Type::None )
         {
             auto* future = new FWString();
-            connect( future, &FWString::finished, [view=this, f=future, h=handler]()
-            {
+            connect( future, &FWString::finished, [view = this, f = future, h = handler]() {
                 QString countryResult = f->future().result();
                 cDebug() << "GeoIP result for welcome=" << countryResult;
                 view->setCountry( countryResult, h );
@@ -154,7 +194,9 @@ WelcomeViewStep::setConfigurationMap( const QVariantMap& configurationMap )
     {
         auto icon = Calamares::Branding::instance()->image( language, QSize( 48, 48 ) );
         if ( !icon.isNull() )
+        {
             m_widget->setLanguageIcon( icon );
+        }
     }
 }
 
@@ -169,7 +211,8 @@ logGeoIPHandler( CalamaresUtils::GeoIP::Handler* handler )
 {
     if ( handler )
     {
-        cDebug() << Logger::SubEntry << "Obtained from" << handler->url() << " (" << static_cast<int>( handler->type() ) << handler->selector() << ')';
+        cDebug() << Logger::SubEntry << "Obtained from" << handler->url() << " ("
+                 << static_cast< int >( handler->type() ) << handler->selector() << ')';
     }
 }
 
@@ -194,8 +237,12 @@ WelcomeViewStep::setCountry( const QString& countryCode, CalamaresUtils::GeoIP::
     {
         int r = CalamaresUtils::Locale::availableTranslations()->find( countryCode );
         if ( r < 0 )
+        {
             cDebug() << "Unusable country code" << countryCode << "(no suitable translation)";
+        }
         if ( ( r >= 0 ) && m_widget )
+        {
             m_widget->externallySelectedLanguage( r );
+        }
     }
 }
