@@ -1,7 +1,7 @@
 /* === This file is part of Calamares - <https://github.com/calamares> ===
  *
  *   Copyright 2014-2015, Teo Mrnjavac <teo@kde.org>
- *   Copyright 2019, Adriaan de Groot <groot@kde.org>
+ *   Copyright 2019-2020, Adriaan de Groot <groot@kde.org>
  *
  *   Calamares is free software: you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -20,25 +20,28 @@
 #ifndef CHECKER_RESULTSLISTWIDGET_H
 #define CHECKER_RESULTSLISTWIDGET_H
 
+#include "ResultWidget.h"
+
 #include "modulesystem/Requirement.h"
 
-#include <QBoxLayout>
 #include <QWidget>
 
+class QLabel;
+
 class ResultsListWidget : public QWidget
 {
     Q_OBJECT
 public:
-    explicit ResultsListWidget( QWidget* parent = nullptr );
-
-    void init( const Calamares::RequirementsList& checkEntries );
+    explicit ResultsListWidget( QWidget* parent, const Calamares::RequirementsList& checkEntries );
 
 private:
-    void showDetailsDialog( const Calamares::RequirementsList& checkEntries );
+    /// @brief A link in the explanatory text has been clicked
+    void linkClicked( const QString& link );
+    void retranslate();
 
-    QBoxLayout* m_mainLayout;
-    QBoxLayout* m_entriesLayout;
-    int m_paddingSize;
+    QLabel* m_explanation = nullptr;  ///< Explanatory text above the list, with link
+    const Calamares::RequirementsList& m_entries;
+    QList< ResultWidget* > m_resultWidgets;  ///< One widget for each unsatisfied entry
 };
 
-#endif // CHECKER_RESULTSLISTWIDGET_H
+#endif  // CHECKER_RESULTSLISTWIDGET_H
